<?php
/*
Plugin Name: Options Framework
Plugin URI: http://www.wptheming.com
Description: A framework for building theme options.
Version: 0.8
Author: Devin Price
Author URI: http://www.wptheming.com
License: GPLv2
*/

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/* Basic plugin definitions */

define('OPTIONS_FRAMEWORK_VERSION', '0.9');
define('THEME_OPTIONS_PAGE', 'Theme Options');
define('SIDEBAR_MANAGER_PAGE', 'Sidebars Manager');
define('SKINS_MANAGER_PAGE', 'Skins Manager');
define('IMAGE_SIZES_PAGE', 'Image Sizes');
define('FONTS_MANAGER_PAGE', 'Fonts Manager');

global $current_location;

/* Make sure we don't expose any info if called directly */

if ( !function_exists( 'add_action' ) ) {
	echo "Hi there!  I'm just a little plugin, don't mind me.";
	exit;
}

/* If the user can't edit theme options, no use running this plugin */

add_action('init', 'optionsframework_rolescheck' );

function optionsframework_rolescheck () {
	ob_start();
	if ( current_user_can( 'edit_theme_options' ) ) {
		// If the user can edit theme options, let the fun begin!		
		add_action( 'admin_menu', 'optionsframework_add_page');
	}

	add_action( 'admin_init', 'optionsframework_init' );
	add_action( 'admin_init', 'optionsframework_mlu_init' );	
}

/* Loads the file for option sanitization */

add_action('init', 'optionsframework_load_sanitization' );

function optionsframework_load_sanitization() {
	require_once dirname( __FILE__ ) . '/options-sanitize.php';
}

/* 
 * Creates the settings in the database by looping through the array
 * we supplied in options.php.  This is a neat way to do it since
 * we won't have to save settings for headers, descriptions, or arguments.
 *
 * Read more about the Settings API in the WordPress codex:
 * http://codex.wordpress.org/Settings_API
 *
 */

function optionsframework_init() {

	// Include the required files
	require_once dirname( __FILE__ ) . '/options-interface.php';
	require_once dirname( __FILE__ ) . '/options-medialibrary-uploader.php';

	// Loads the options array from the theme
	require_once dirname( __FILE__ ) . '/options.php';
	
	$optionsframework_settings = get_option('optionsframework' );
	
	// Updates the unique option id in the database if it has changed
	optionsframework_option_name();
	
	// Gets the unique id, returning a default if it isn't defined
	if ( isset($optionsframework_settings['id']) ) {
		$option_name = $optionsframework_settings['id'];
	}
	else {
		$option_name = 'optionsframework';
	}
	
	// If the option has no saved data, load the defaults
	if ( ! get_option($option_name) ) {
		optionsframework_setdefaults();
	}
	
	// Registers the settings fields and callback
	register_setting( 'optionsframework', $option_name, 'optionsframework_validate' );
}

/* 
 * Adds default options to the database if they aren't already present.
 * May update this later to load only on plugin activation, or theme
 * activation since most people won't be editing the options.php
 * on a regular basis.
 *
 * http://codex.wordpress.org/Function_Reference/add_option
 *
 */

function optionsframework_setdefaults() {
	global $current_location;
	
	$optionsframework_settings = get_option('optionsframework');

	// Gets the unique option id
	$option_name = $optionsframework_settings['id'];
	
	/* 
	 * Each theme will hopefully have a unique id, and all of its options saved
	 * as a separate option set.  We need to track all of these option sets so
	 * it can be easily deleted if someone wishes to remove the plugin and
	 * its associated data.  No need to clutter the database.  
	 *
	 */
	
	if ( isset($optionsframework_settings['knownoptions']) ) {
		$knownoptions =  $optionsframework_settings['knownoptions'];
		if ( !in_array($option_name, $knownoptions) ) {
			array_push( $knownoptions, $option_name );
			$optionsframework_settings['knownoptions'] = $knownoptions;
			update_option('optionsframework', $optionsframework_settings);
		}
	} else {
		$newoptionname = array($option_name);
		$optionsframework_settings['knownoptions'] = $newoptionname;
		update_option('optionsframework', $optionsframework_settings);
	}
	
	// Gets the default options data from the array in options.php
	$options = optionsframework_options();
	
	// If the options haven't been added to the database yet, they are added now
	$values = of_get_default_values( $current_location );
	
	if ( isset($values) ) {
		add_option( $option_name, $values ); // Add option with default settings
	}
}

/* Add a subpage called "Theme Options" to the appearance menu. */

if ( !function_exists( 'optionsframework_add_page' ) ) {
function optionsframework_add_page() {

	// Main theme menu
	$of_page = add_menu_page(UNISPHERE_THEMENAME . ' theme options', UNISPHERE_THEMENAME, 'edit_theme_options', 'options-framework', 'optionsframework_page', UNISPHERE_ADMIN_IMAGES . '/theme_icon.png', 105);

	// Theme options sub-menu
	add_submenu_page('options-framework', UNISPHERE_THEMENAME . ' theme options', 'Theme options', 'edit_theme_options', 'options-framework', 'optionsframework_page');

	// Adds actions to hook in the required css and javascript
	add_action("admin_print_styles-$of_page",'optionsframework_load_styles');
	add_action("admin_print_scripts-$of_page", 'optionsframework_load_scripts');

	// Image sizes settings sub-menu
	$of_page = add_submenu_page('options-framework', UNISPHERE_THEMENAME . ' image sizes', 'Image sizes', 'edit_theme_options', 'options-framework-image-sizes', 'optionsframework_imagesizes_page');

	// Adds actions to hook in the required css and javascript
	add_action("admin_print_styles-$of_page",'optionsframework_load_styles');
	add_action("admin_print_scripts-$of_page", 'optionsframework_load_scripts');

	// Skins manager sub-menu
	$of_page = add_submenu_page('options-framework', UNISPHERE_THEMENAME . ' skins manager', 'Skins manager', 'edit_theme_options', 'options-framework-skins-manager', 'optionsframework_skinsmanager_page');

	// Adds actions to hook in the required css and javascript
	add_action("admin_print_styles-$of_page",'optionsframework_load_styles');
	add_action("admin_print_scripts-$of_page", 'optionsframework_load_scripts');

	// Fonts manager sub-menu
	$of_page = add_submenu_page('options-framework', UNISPHERE_THEMENAME . ' fonts manager', 'Fonts manager', 'edit_theme_options', 'options-framework-fonts-manager', 'optionsframework_fontsmanager_page');

	// Adds actions to hook in the required css and javascript
	add_action("admin_print_styles-$of_page",'optionsframework_load_styles');
	add_action("admin_print_scripts-$of_page", 'optionsframework_load_scripts');

	// Sidebar manager sub-menu
	$of_page = add_submenu_page('options-framework', UNISPHERE_THEMENAME . ' sidebar manager', 'Sidebars manager', 'edit_theme_options', 'options-framework-sidebar-manager', 'optionsframework_sidebarmanager_page');

	// Adds actions to hook in the required css and javascript
	add_action("admin_print_styles-$of_page",'optionsframework_load_styles');
	add_action("admin_print_scripts-$of_page", 'optionsframework_load_scripts');
}
}

/* Loads the CSS */

function optionsframework_load_styles() {
	wp_enqueue_style('admin-style', OPTIONS_FRAMEWORK_DIRECTORY.'css/admin-style.css');
	wp_enqueue_style('color-picker', OPTIONS_FRAMEWORK_DIRECTORY.'css/colorpicker.css');
}	

/* Loads the javascript */

function optionsframework_load_scripts() {

	// Inline scripts from options-interface.php
	add_action('admin_head', 'of_admin_head');
	
	// Enqueued scripts
	wp_enqueue_script('jquery-ui-core');
	wp_enqueue_script('color-picker', OPTIONS_FRAMEWORK_DIRECTORY.'js/colorpicker.js', array('jquery'));
	wp_enqueue_script('options-custom', OPTIONS_FRAMEWORK_DIRECTORY.'js/options-custom.js', array('jquery'));
}

function of_admin_head() {

	// Hook to add custom scripts
	do_action( 'optionsframework_custom_scripts' );
}

/* 
 * Builds out the options panel.
 *
 * If we were using the Settings API as it was likely intended we would use
 * do_settings_sections here.  But as we don't want the settings wrapped in a table,
 * we'll call our own custom optionsframework_fields.  See options-interface.php
 * for specifics on how each individual field is generated.
 *
 * Nonces are provided using the settings_fields()
 *
 */

function optionsframework_page() {
	global $current_location;
	$current_location = THEME_OPTIONS_PAGE;
	optionsframework_buildpage();
}

function optionsframework_sidebarmanager_page() {
	global $current_location;
	$current_location = SIDEBAR_MANAGER_PAGE;
	optionsframework_buildpage();
}

function optionsframework_skinsmanager_page() {
	global $current_location;
	$current_location = SKINS_MANAGER_PAGE;
	optionsframework_buildpage();
}

function optionsframework_fontsmanager_page() {
	global $current_location;
	$current_location = FONTS_MANAGER_PAGE;
	optionsframework_buildpage();
}

function optionsframework_imagesizes_page() {
	global $current_location;
	$current_location = IMAGE_SIZES_PAGE;
	optionsframework_buildpage();
}

if ( !function_exists( 'optionsframework_buildpage' ) ) {
function optionsframework_buildpage() {
	global $current_location;
	global $current_user;
	get_currentuserinfo();

	// Save the generated skin.css file to the skin folder
	if( $current_location == SKINS_MANAGER_PAGE ) {	

		// Check if there's a new skin to download and import
		if ( isset($_REQUEST['action']) && $_REQUEST['action'] == 'download' ) {
			if( isset($_REQUEST['name']) && wp_verify_nonce($_REQUEST['_wpnonce'], 'skin_browser_download_skin_id_' . $_REQUEST['name']) ) {
				if( false === ( $skin_browser_data = get_transient( UNISPHERE_THEMEOPTIONS . '-skin-browser' ) ) ) {
			    	$response = wp_remote_get( UNISPHERE_SKINS_BROWSER_FILE );
					if( is_wp_error( $response ) ) {
						wp_die('An error occurred when accessing remote server, please try again later.');
					} else {
						$skin_browser_data = $response['body'];
					}

					// Cache the remote query for 1 hour
					set_transient( UNISPHERE_THEMEOPTIONS . '-skin-browser', $skin_browser_data, 60 * 60 );
				}

				// Let's see if the xml data was returned as we expected it to
				if( strpos((string)$skin_browser_data, '<skin_browser>') === false ) {
					wp_die('An error occurred when accessing remote server, please try again later.');
				}
				
				$skin_browser_data = simplexml_load_string($skin_browser_data); 

				$download_url = $skin_browser_data->download_url;

				// Download remote skin zip file
				$tmp = download_url( str_replace( '#FILE#', $_REQUEST['name'], $download_url ) . $_REQUEST['name'] . '.zip' );

		        if ( is_wp_error( $tmp ) ) {
		            @unlink($tmp);		            
		            wp_die('An error occurred when importing the skin, please try again later.<br /><br /><strong>Error: ' . $tmp->get_error_message() . '</strong>');
		        }

				$new_skin_name = '_downloaded_' . str_replace( ' ', '_', $_REQUEST['name'] );
				if( is_multisite() ) 
					$new_skin_name = '_multisite' . $new_skin_name;
				$skin_import_data = array('skin_import_file' => $tmp, 'new_skin_name' => $new_skin_name);

				// Flag this skin to be imported on the next page load
				update_option('unisphere_skin_import_' . $current_user->ID, $skin_import_data);

				// Delete the cached data for the fonts
				delete_transient( UNISPHERE_THEMEOPTIONS . '-enqueue_google_fonts' );
				delete_transient( UNISPHERE_THEMEOPTIONS . '-enqueue_cufon_fonts' );
				delete_transient( UNISPHERE_THEMEOPTIONS . '-cufon_selectors' );

				$options = optionsframework_options();
				foreach ( $options as $option ) {
					if ( ! isset( $option['id'] ) ) {
						continue;
					}
					if ( ! isset( $option['type'] ) ) {
						continue;
					}
					$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );
					if ( isset( $option['location'] ) && $option['location'] == SKINS_MANAGER_PAGE ) {
						// In case of a skin import clear all values so they get loaded in the next page load instead
						of_update_option($id, '');
					}
				}

				of_update_option( 'skin_current', $new_skin_name);

				wp_redirect( self_admin_url('admin.php?page=options-framework-skins-manager') );
				exit;
			} else {
				wp_die('Access denied');
			}
		}

		// Check if there's a new skin to create
		$skin_to_create = get_option('unisphere_skin_create_' . $current_user->ID);
		if( !empty( $skin_to_create ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;
				
				// If is multisite check if the /skins/site_id/ folder is created
				if( is_multisite() ) {
					if ( !$wp_filesystem->mkdir(truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id()), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() ) ) ) { // Only check to see if the Dir exists upon creation failure. Less I/O this way.
						// let's mitigate some damage if there aren't enough permissions (set current skin to the previously used skin)
						delete_option('unisphere_skin_create_' . $current_user->ID);
						of_update_option( 'skin_current', basename($skin_to_create['base_skin_folder']));
						wp_die( "Could not create directory " . truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() ) . "\n" );
					}
				}

				// Create folder to hold the new skin files
				if ( !$wp_filesystem->mkdir($skin_to_create['new_skin_folder'], FS_CHMOD_DIR) && !$wp_filesystem->is_dir($skin_to_create['new_skin_folder']) ) { // Only check to see if the Dir exists upon creation failure. Less I/O this way.
					// let's mitigate some damage if there aren't enough permissions (set current skin to the previously used skin)
					delete_option('unisphere_skin_create_' . $current_user->ID);
					of_update_option( 'skin_current', basename($skin_to_create['base_skin_folder']));
					wp_die( "Could not create directory " . $skin_to_create['new_skin_folder'] . "\n" );
				}

				// Copy base skin files to the new skin folder
				// (Assumes that WP_Filesystem() has already been called and setup)
				$result = copy_dir( $skin_to_create['base_skin_folder'], $skin_to_create['new_skin_folder'] );
				if( is_wp_error($result) ) {
					// let's mitigate some damage if there aren't enough permissions (set current skin to the previously used skin)
					delete_option('unisphere_skin_create_' . $current_user->ID);
					of_update_option( 'skin_current', basename($skin_to_create['base_skin_folder']));
					wp_die( 'Could not copy from base skin folder to new skin folder.<br /><br /><strong>Error: ' . $result->get_error_message() . '</strong>' );
				}

				delete_option('unisphere_skin_create_' . $current_user->ID);

				// Grab the skin.php file and generate a new skin.css file
				$response = wp_remote_get( UNISPHERE_CSS . '/skin.php' );
				if( is_wp_error( $response ) || $response['response']['code'] != 200 ) {
					// Let's try an alternate approach		
					$filename = truepath( TEMPLATEPATH . '/css/skin.php' );
					ob_start();
					include $filename;
					$content = ob_get_contents();
					ob_end_clean();
				} else {
					$content = $response['body'];
				}

				// Save the rendered skin.css file into the new skin folder
				if ($content !== false) {
					$cssFile = truepath( TEMPLATEPATH . '/css/skins/' . basename($skin_to_create['new_skin_folder']) . '/skin.css' );
					if( is_multisite() )
						$cssFile = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . basename($skin_to_create['new_skin_folder']) . '/skin.css' );
					if ( !$wp_filesystem->put_contents( $cssFile, $content, FS_CHMOD_FILE) ) {
						// let's mitigate some damage if there aren't enough permissions
						wp_die( "Can't generate new skin CSS file &lt;" . $cssFile . "><br /><br />Please check file/folder permissions and/or ownership." );
					}
				}

				$skin_to_create = null;
				add_settings_error( 'options-framework', 'skin_create', __( 'New skin created.', 'optionsframework' ), 'updated fade' );
			}
		}

		// Check if there's any skin to delete
		$skin_to_delete = get_option('unisphere_skin_delete_' . $current_user->ID);
		if( !empty( $skin_to_delete ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;
				if( is_multisite() ) {
					$wp_filesystem->delete( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $skin_to_delete ), true );
				} else {
					$wp_filesystem->delete( truepath( TEMPLATEPATH . '/css/skins/' . $skin_to_delete ), true );
				}

				// Delete the backup of the skin that is outside of the theme folder
				deleteSkinBackup( $skin_to_delete );

				delete_option('unisphere_skin_delete_' . $current_user->ID);
				$skin_to_delete = null;
				add_settings_error( 'options-framework', 'skin_delete', __( 'Skin deleted.', 'optionsframework' ), 'updated fade' );
			}
		}

		// Check if there's a new skin to import
		$skin_to_import = get_option('unisphere_skin_import_' . $current_user->ID);
		if( !empty( $skin_to_import ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;

				// If is multisite check if the /skins/site_id/ folder is created
				if( is_multisite() ) {
					if ( !$wp_filesystem->mkdir(truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id()), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() ) ) ) { // Only check to see if the Dir exists upon creation failure. Less I/O this way.
						// let's mitigate some damage if there aren't enough permissions (set current skin to the previously used skin)
						delete_option('unisphere_skin_import_' . $current_user->ID);						
						wp_die( "Could not create directory " . truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() ) . "\n" );
					}
				}

				$file_info = pathinfo( $skin_to_import['skin_import_file'] );  				
				// Check if the file was downloaded...
				if( $file_info['extension'] == 'tmp' ) {
					// Change file extension to ZIP
					$wp_filesystem->move( $skin_to_import['skin_import_file'], str_replace('.tmp', '.zip', $skin_to_import['skin_import_file']) );
					$skin_to_import['skin_import_file'] = str_replace('.tmp', '.zip', $skin_to_import['skin_import_file']);
					if( unzipSkinFile( truepath( $skin_to_import['skin_import_file'] ), $skin_to_import['new_skin_name'] ) ) {
						@unlink($skin_to_import['skin_import_file']);
						// load the json file for the skin
						$skin_data = getSkinJsonToArray( UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $skin_to_import['new_skin_name'] . '/settings.json' );
						for ( $i=0 ; $i<count($skin_data) ; $i++ ) {
							foreach ( $skin_data[$i] as $key => $value ) {
								if( is_array($value) && !empty($value['image']) ) {
									$value['image'] = UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $skin_to_import['new_skin_name'] . '/' . basename($value['image']);
								}
								of_update_option($key, $value);
							}
						}
						add_settings_error( 'options-framework', 'skin_download', __( 'New skin downloaded.', 'optionsframework' ), 'updated fade' );
					} else {
						add_settings_error( 'options-framework', 'skin_download', __( 'There was a problem downloading the new skin.', 'optionsframework' ), 'error fade' );
					}
				} else { // ...or imported directly
					$zip_file = truepath(ABSPATH . '/wp-content/uploads') . substr( $skin_to_import['skin_import_file'], strpos( $skin_to_import['skin_import_file'], '/wp-content/uploads/' ) + 19 );
					// is multisite?
					if( is_multisite() && contains('/files/', $skin_to_import['skin_import_file']) ) {						
						$file_parts = explode('/files/', $skin_to_import['skin_import_file']);
						$zip_file = truepath(ABSPATH . 'wp-content/blogs.dir/' . get_current_blog_id() . '/files/' . $file_parts[1]);
					}

					if( unzipSkinFile( $zip_file, $skin_to_import['new_skin_name'] ) ) {
						// load the json file for the skin
						$skin_data = getSkinJsonToArray( UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $skin_to_import['new_skin_name'] . '/settings.json' );
						for ( $i=0 ; $i<count($skin_data) ; $i++ ) {
							foreach ( $skin_data[$i] as $key => $value ) {
								if( is_array($value) && !empty($value['image']) ) {
									$value['image'] = UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $skin_to_import['new_skin_name'] . '/' . basename($value['image']);
								}
								of_update_option($key, $value);
							}
						}
						add_settings_error( 'options-framework', 'skin_import', __( 'New skin imported.', 'optionsframework' ), 'updated fade' );
					} else {
						add_settings_error( 'options-framework', 'skin_import', __( 'There was a problem importing the new skin.', 'optionsframework' ), 'error fade' );
					}
				}
				delete_option('unisphere_skin_import_' . $current_user->ID);

				// Grab the skin.php file and generate a new skin.css file
				$response = wp_remote_get( UNISPHERE_CSS . '/skin.php' );
				if( is_wp_error( $response ) || $response['response']['code'] != 200 ) {
					// Let's try an alternate approach		
					$filename = truepath( TEMPLATEPATH . '/css/skin.php' );
					global $unisphere_options;
					$unisphere_options = get_option( UNISPHERE_THEMEOPTIONS );
					ob_start();
					include $filename;
					$content = ob_get_contents();
					ob_end_clean();
				} else {
					$content = $response['body'];
				}

				// Save the rendered skin.css file into the skin folder
				if ($content !== false) {
					$cssFile = truepath( TEMPLATEPATH . '/css/skins/' . $skin_to_import['new_skin_name'] . '/skin.css' );
					if( is_multisite() )
						$cssFile = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $skin_to_import['new_skin_name'] . '/skin.css' );
					if ( !$wp_filesystem->put_contents( $cssFile, $content, FS_CHMOD_FILE) ) {
						// let's mitigate some damage if there aren't enough permissions
						wp_die( "Can't generate new skin CSS file &lt;" . $cssFile . "><br /><br />Please check file/folder permissions and/or ownership." );
					}
				}

				$skin_to_import = null;
			}
		}

		// Check if there's a skin settings update
		$skin_to_update = get_option('unisphere_skin_update_' . $current_user->ID);
		if( !empty( $skin_to_update ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;
				// Copy any background images from the background fields to the skin folder
				if( !empty( $skin_to_update['images_to_copy'] ) ) {
					foreach ( $skin_to_update['images_to_copy'] as $data ) {
						if( $wp_filesystem->copy($data['source_path'] , $data['dest_path'], true, FS_CHMOD_FILE ) ) {
							of_update_option($data['option_id'], $data['dest_url'], 'image');
						}
					}
				}

				// Try and delete image files that the user has removed
				if( !empty( $skin_to_update['images_to_delete'] ) ) {
					foreach ( $skin_to_update['images_to_delete'] as $image_to_delete ) {
						$wp_filesystem->delete( $image_to_delete );
					}
				}

				// Grab the skin.php file and generate the skin.css file for the current selected skin
				$response = wp_remote_get( UNISPHERE_CSS . '/skin.php' );
				if( is_wp_error( $response ) || $response['response']['code'] != 200 ) {
					// Let's try an alternate approach		
					$filename = truepath( TEMPLATEPATH . '/css/skin.php' );
					ob_start();
					include $filename;
					$content = ob_get_contents();
					ob_end_clean();
				} else {
					$content = $response['body'];
				}

				// Save the rendered skin.css file into the skin folder
				if ($content !== false) {
					$cssFile = truepath( TEMPLATEPATH . '/css/skins/' . of_get_option('skin_current') . '/skin.css' );
					if( is_multisite() )
						$cssFile = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . of_get_option('skin_current') . '/skin.css' );
					if ( !$wp_filesystem->put_contents( $cssFile, $content, FS_CHMOD_FILE) ) {
						// let's mitigate some damage if there aren't enough permissions
						delete_option('unisphere_skin_update_' . $current_user->ID);
						wp_die( "Can't generate new skin CSS file &lt;" . $cssFile . "><br /><br />Please check file/folder permissions and/or ownership." );
					}
				}

				// Save the skin settings in a JSON file		
				$optionsframework_settings = get_option('optionsframework');

				// Gets the unique option id
				if (isset($optionsframework_settings['id'])) {
					$option_name = $optionsframework_settings['id'];
				}
				else {
					$option_name = 'optionsframework';
				};

				$settings = get_option($option_name);
				$options = optionsframework_options();
				$options_to_export = array();		
				foreach ($options as $value) {
					if( isset( $value['location'] ) && $value['location'] == SKINS_MANAGER_PAGE && ( $value['type'] == 'color' || $value['type'] == 'background' || $value['type'] == 'select' || $value['type'] == 'textarea' || $value['type'] == 'text' || $value['type'] == 'typography' ) && isset( $settings[$value['id']] ) ) {
						$options_to_export[] = array($value['id'] => $settings[$value['id']]);
					}	
				}

				$jsonFile = truepath( TEMPLATEPATH . '/css/skins/' . of_get_option('skin_current') . '/settings.json' );
				if( is_multisite() )
				   	$jsonFile = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . of_get_option('skin_current') . '/settings.json' );
				if ( !$wp_filesystem->put_contents( $jsonFile, json_encode( $options_to_export ), FS_CHMOD_FILE) ) {
					// let's mitigate some damage if there aren't enough permissions
				   	delete_option('unisphere_skin_update_' . $current_user->ID);
					wp_die( "Can't write new skin settings to file &lt;" . $jsonFile . "><br /><br />Please check file/folder permissions and/or ownership." );
				}

				// Create a backup of the skin outside of the theme folder
				createSkinBackup( of_get_option('skin_current') );

				delete_option('unisphere_skin_update_' . $current_user->ID);
				$skin_to_update = null;
				add_settings_error( 'options-framework', 'save_options', __( 'Options saved.', 'optionsframework' ), 'updated fade' );
			}
		}
	}

	// Save the generated custom-image-sizes.css file to the css folder
	if( $current_location == IMAGE_SIZES_PAGE ) {

		// Check if there's a skin settings update
		$image_sizes_update = get_option('unisphere_image_sizes_update_' . $current_user->ID);
		if( !empty( $image_sizes_update ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;

				$response = wp_remote_get( UNISPHERE_CSS . '/custom-image-sizes.php' );
				if( is_wp_error( $response ) || $response['response']['code'] != 200 ) {
					// Let's try an alternate approach		
					$filename = truepath( TEMPLATEPATH . '/css/custom-image-sizes.php' );
					ob_start();
					include $filename;
					$content = ob_get_contents();
					ob_end_clean();
				} else {
					$content = $response['body'];
				}

				// Save the rendered custom-image-sizes.css file into the skin folder
				if ($content !== false) {
					$cssFile = truepath( TEMPLATEPATH . '/css/custom-image-sizes.css' );

					if( is_multisite() )
				   		$cssFile = truepath( TEMPLATEPATH . '/css/custom-image-sizes-multisite-' . get_current_blog_id() . '.css' );
				   					   		
				   	if ( !$wp_filesystem->put_contents( $cssFile, $content, FS_CHMOD_FILE) ) {
				   		// let's mitigate some damage if there aren't enough permissions
				   		delete_option('unisphere_image_sizes_update_' . $current_user->ID);						
						wp_die( "Can't generate CSS file for new image sizes &lt;" . $cssFile . "><br /><br />Please check file/folder permissions and/or ownership." );
					}
				} 

				delete_option('unisphere_image_sizes_update_' . $current_user->ID);
				$image_sizes_update = null;
				add_settings_error( 'options-framework', 'save_options', __( 'Options saved.', 'optionsframework' ), 'updated fade' );
			}
		}
	}

	// Save the uploaded cufon font to the "fonts" folder
	if( $current_location == FONTS_MANAGER_PAGE ) {

		// Check if there's a new cufon font upload
		$cufon_upload_file = get_option('unisphere_cufon_upload_' . $current_user->ID);
		if( !empty( $cufon_upload_file ) ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;
				if( $wp_filesystem->copy($cufon_upload_file['source_path'], $cufon_upload_file['dest_path'], true, FS_CHMOD_FILE ) ) {
					// Create a backup of the font outside of the theme folder
					createFontBackup( $cufon_upload_file['dest_path'] );

					delete_transient('cufon_fonts');
					delete_option('unisphere_cufon_upload_' . $current_user->ID);
					$cufon_upload_file = null;
					add_settings_error( 'options-framework', 'cufon_upload', __( 'New Cufon font added.', 'optionsframework' ), 'updated fade' );
				} else {
					// let's mitigate some damage if there aren't enough permissions
				   	delete_option('unisphere_cufon_upload_' . $current_user->ID);
					add_settings_error( 'options-framework', 'cufon_upload', __( 'An error occurred when adding the new Cufon font.', 'optionsframework' ), 'error' );
				}
			}
		}
	}

	// No page-load operations to be made, so show the options panel
	if( empty( $skin_to_create ) && empty( $skin_to_delete ) && empty( $skin_to_import ) && empty( $skin_to_update ) && empty( $image_sizes_update ) && empty( $cufon_upload_file ) ) :

		$return = optionsframework_fields( $current_location );
		settings_errors();	?>
	    
		<div class="wrap">
		    <?php screen_icon( 'themes' ); ?>
		    <?php if( $current_location == SKINS_MANAGER_PAGE ) : ?>
		    <span id="current-skin">Current skin: <strong><?php echo str_replace( '_', ' ', str_replace('_theme_', '', str_replace('_downloaded_', '', str_replace('_multisite_', '', str_replace('_multisite_downloaded_', '', of_get_option( 'skin_current' ) ) ) ) ) ); ?></strong></span>
		    <?php endif; ?>
		    <h2><?php echo $current_location; ?></h2>
		    <?php if( $current_location == SKINS_MANAGER_PAGE ) {
		    	restoreBackups(); 
		    } ?>
		    <h2 class="nav-tab-wrapper">
		        <?php echo $return[1]; ?>
		    </h2>
		    
		    <div class="metabox-holder">
			    <div id="optionsframework" class="postbox optionsframework-<?php echo sanitize_title( $current_location ); ?>">
					<form action="options.php" method="post">
						<?php settings_fields('optionsframework'); ?>
						<input type="hidden" name="options_framework_page" value="<?php echo $current_location; ?>" />

						<?php echo $return[0]; /* Settings */  ?>
				        
				        <div id="optionsframework-submit">
							<input type="submit" class="button-primary" name="update" value="<?php esc_attr_e( 'Save Options' ); ?>" />
							<?php if( $current_location != SKINS_MANAGER_PAGE && $current_location != SIDEBAR_MANAGER_PAGE ) : ?>
				            <input type="submit" class="reset-button button-secondary" name="reset" value="<?php esc_attr_e( 'Restore Defaults' ); ?>" onclick="return confirm( '<?php print esc_js( __( 'Click OK to reset. Any theme settings will be lost!', 'optionsframework' ) ); ?>' );" />
				            <?php endif; ?>
				            <div class="clear"></div>
						</div>
					</form>
				</div> <!-- / #container -->
			</div>
		</div> <!-- / .wrap -->

<?php 
	endif;
}
}


function unisphere_check_credentials( $current_location ) {
	if( $current_location != SKINS_MANAGER_PAGE && $current_location != IMAGE_SIZES_PAGE && $current_location != FONTS_MANAGER_PAGE )
		return false;

	if( $current_location == SKINS_MANAGER_PAGE )
		$page_url = 'options-framework-skins-manager';

	if( $current_location == IMAGE_SIZES_PAGE )
		$page_url = 'options-framework-image-sizes';
	
	if( $current_location == FONTS_MANAGER_PAGE )
		$page_url = 'options-framework-fonts-manager';

	$help  = '<div id="message" class="updated below-h2" style="margin-left: 0;"><p><strong>Important Note</strong> (please read)</p></div>';
	$help .= '<p>This particular section of the theme admin panel needs to create/edit some files but your server configuration doesn\'t allow direct access to the file system.</p>';
	$help .= '<p>WordPress has detected this and requires FTP credentials. In order to procede you can either provide the FTP credentials everytime you want to change any setting in this section or provide your FTP details in your <strong>wp-config.php</strong> file just one time.</p>';
	$help .= '<br /><p><strong>These settings work on most servers:</strong><br /><small>(adjust FTP_USER, FTP_PASS and FTP_HOST according to your server config)</small></p>';
	$help .= "<pre>define('FS_METHOD', 'ftpext');\n";
	$help .= "define('FTP_USER', 'username');\n";
	$help .= "define('FTP_PASS', 'password');\n";
	$help .= "define('FTP_HOST', 'ftp.example.org');</pre>";
	$help .= "<br /><p>Sometimes WordPress requires some extra information. If the above settings aren't enough try adding the following also:<br /><small>(adjust FTP_BASE according to your server config)</small></p>";
	$help .= "<pre>define('FTP_BASE', '/path/to/wordpress/');\n";
	$help .= "define('FTP_SSL', false);</pre>";

	@ini_set( 'memory_limit', apply_filters( 'admin_memory_limit', WP_MAX_MEMORY_LIMIT ) );
    @set_time_limit( 0 );

	// okay, let's see about getting credentials
	$url = wp_nonce_url('admin.php?page=' . $page_url);
	if (false === ($creds = request_filesystem_credentials($url, '', false, false, null) ) ) {
	
		// if we get here, then we don't have credentials yet,
		// but have just produced a form for the user to fill in, 
		// so stop processing for now
		echo $help;
		return false;
	}
		
	// now we have some credentials, try to get the wp_filesystem running
	if ( ! WP_Filesystem($creds) ) {
		// our credentials were no good, ask the user for them again
		request_filesystem_credentials($url, '', true, false, null);
		echo $help;
		return false;
	}
	
	return true;
}


/** 
 * Validate Options.
 *
 * This runs after the submit/reset button has been clicked and
 * validates the inputs.
 */
function optionsframework_validate( $input ) {
	$location = $_POST['options_framework_page'];
	global $current_user;
	get_currentuserinfo();

	$new_skin_name = '';
	$skin_update = false;

	/*
	 * The "Save options" button has been hit and this is the Skin Manager page
	 */

	if( isset( $_POST['update'] ) && $location == SKINS_MANAGER_PAGE ) {
		$skin_update = true;
	}

	/*
	 * The "Save options" button has been hit and this is the Image sizes page
	 */

	if( ( isset( $_POST['update'] ) || isset( $_POST['reset'] ) ) && $location == IMAGE_SIZES_PAGE ) {
		// Flag the custom image sizes css file to be generated on the next page load
		update_option('unisphere_image_sizes_update_' . $current_user->ID, true);
	}

	/*
	 * Create a new skin from an existing one 
	 */

	if ( isset( $_POST['skin_create'] ) ) {
		// New skin settings
		$base_skin = $input['skin_create_select'];
		$new_skin_name = str_replace( ' ', '_', $input['skin_create_text'] );
		$base_skin_folder = truepath( TEMPLATEPATH . '/css/skins/' . $base_skin );
		$new_skin_folder = truepath( TEMPLATEPATH . '/css/skins/' . $new_skin_name );
		if( is_multisite() ) {
			if( startsWith( basename($base_skin), '_multisite_' ) ) {
				$base_skin_folder = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $base_skin );
			}
			$new_skin_folder = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/_multisite_' . $new_skin_name );
			$new_skin_name = '_multisite_' . $new_skin_name;
		}
		$skin_create_data = array('base_skin_folder' => $base_skin_folder, 'new_skin_folder' => $new_skin_folder);

		// Flag this skin to be created on the next page load
		update_option('unisphere_skin_create_' . $current_user->ID, $skin_create_data);

		// Make the newly created skin the current one
		$input['skin_current'] = $new_skin_name;
		$_POST['skin_current'] = $new_skin_name;
	}

	/*
	 * Delete a skin
	 */

	if ( isset( $_POST['skin_delete'] ) ) {		
		// Flag this skin to be deleted on the next page load
		update_option('unisphere_skin_delete_' . $current_user->ID, $input['skin_delete_select']);
		$_POST['skin_current'] = $input['skin_current'];
	}

	/*
	 * Import new skin and unzip it 
	 */

	if ( isset( $_POST['skin_import'] ) ) {
		$new_skin_name = str_replace( ' ', '_', $input['skin_import_text'] );
		if( is_multisite() )
			$new_skin_name = '_multisite_' . $new_skin_name;
		
		$skin_import_data = array('skin_import_file' => $input['skin_import_file'], 'new_skin_name' => $new_skin_name);

		// Flag this skin to be imported on the next page load
		update_option('unisphere_skin_import_' . $current_user->ID, $skin_import_data);

		$input['skin_current'] = $new_skin_name;
		$_POST['skin_current'] = $new_skin_name;
	}

	/*
	 * Export skin and provide it in a ZIP file 
	 */

	if ( isset( $_POST['skin_export'] ) ) {
		if( is_multisite() && startsWith( $input['skin_current'], '_multisite_' ) ) 
			zipFolderAndDownload( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $input['skin_current'] ) ); 
		else
			zipFolderAndDownload( truepath( TEMPLATEPATH . '/css/skins/' . $input['skin_current'] ) ); 
		add_settings_error( 'options-framework', 'skin_export', __( 'Skin exported.', 'optionsframework' ), 'updated fade' );
		return null;
	}

	/*
	 * Create a new sidebar
	 */

	if ( isset( $_POST['sidebar_create'] ) ) {
		$new_sidebar_name = $input['sidebar_create_text'];

		// Check for an existing sidebar with the same name
		$sidebar_exists = false;
		if( !empty( $input['sidebar_list'] ) ) {
			foreach($input['sidebar_list'] as $elementKey => $element) {
			    foreach($element as $valueKey => $value) {
			        if($valueKey == 'name' && $value == $new_sidebar_name)
			            $sidebar_exists = true;
			    }
			}
		}

		if( trim( $new_sidebar_name ) != '' && !$sidebar_exists ) 
			$input['sidebar_list'][] = Array( 'name' => $new_sidebar_name, 'id' => sanitize_title( $new_sidebar_name ) );
		else {
			$_POST['sidebar_create'] = null;
			$_POST['sidebar_exists'] = 'true';
		}
		
		$_POST['update'] = 'true';
	}

	/*
	 * Delete a sidebar
	 */

	if ( isset( $_POST['sidebar_delete'] ) ) {
		foreach($input['sidebar_list'] as $elementKey => $element) {
		    foreach($element as $valueKey => $value) {
		        if($valueKey == 'id' && $value == $_POST['sidebar_delete']) {
		            unset($input['sidebar_list'][$elementKey]);
		        } 
		    }
		}
		$_POST['update'] = 'true';
	}

	/*
	 * Update Google Web Fonts from the remote list
	 */
	if( isset( $_POST['fonts_update_google'] ) ) {
		getGoogleFonts(true);
		$_POST['update'] = 'true';
	}

	/*
	 * Upload a new cufon font script
	 */

	if ( isset( $_POST['cufon_upload'] ) ) {
		$source_path = truepath(ABSPATH . '/wp-content/uploads') . substr( $input['cufon_upload_file'], strpos( $input['cufon_upload_file'], '/wp-content/uploads/' ) + 19 );
		if( contains( '/files/', $input['cufon_upload_file'] ) && is_multisite() ) {
			$file_parts = explode('/files/', $input['cufon_upload_file']);
			$source_path = truepath(ABSPATH . 'wp-content/blogs.dir/' . get_current_blog_id() . '/files/' . $file_parts[1]);
		}
		$dest_path = truepath( TEMPLATEPATH . '/fonts/' . end( explode( '/', str_replace('\\', '/', $input['cufon_upload_file']))));

		if( is_multisite() )
			$dest_path = truepath( TEMPLATEPATH . '/fonts/_multisite_' . get_current_blog_id() . '_' . end( explode( '/', str_replace('\\', '/', $input['cufon_upload_file']))));

		$cufon_upload_data = array('source_path' => $source_path, 'dest_path' => $dest_path);

		// Flag this cufon script file to be copied to the "fonts" folder on the next page load
		update_option('unisphere_cufon_upload_' . $current_user->ID, $cufon_upload_data);
	
		$_POST['update'] = 'true';
	}

	/*
	 * Restore Defaults.
	 *
	 * In the event that the user clicked the "Restore Defaults"
	 * button, the options defined in the theme's options.php
	 * file will be added to the option for the active theme.
	 */
	 
	if ( isset( $_POST['reset'] ) ) {
		add_settings_error( 'options-framework', 'restore_defaults', __( 'Default options restored.', 'optionsframework' ), 'updated fade' );
		return of_get_default_values( $location );
	}

	/*
	 * Update Settings.
	 */
	 
	if ( isset( $_POST['update'] ) || isset( $_POST['skin_current'] ) ) {
		$clean = array();

		// Let's see if the user is importing theme settings
		if ( isset( $input['import_settings'] ) && $input['import_settings'] != '' ) {
			$settings_to_import = base64_decode( $input['import_settings'] );
			$settings_to_import = @unserialize($settings_to_import);

			if( $settings_to_import )
				return $settings_to_import;
		}

		$options = optionsframework_options();
		$skin_json_data = array();

		// In case of current skin change or create, load the json file for the skin
		if ( isset( $_POST['skin_current'] ) && !isset( $_POST['skin_import'] ) ) {
			// When creating a new skin load the base skin settings
			if ( isset( $_POST['skin_create'] ) ) {
				if( is_multisite() && startsWith($base_skin, '_multisite_') )
					$skin_data = getSkinJsonToArray( UNISPHERE_CSS . '/skins/_multisite_' . get_current_blog_id() . '/' . $base_skin . '/settings.json' );
				else
					$skin_data = getSkinJsonToArray( UNISPHERE_CSS . '/skins/' . $base_skin . '/settings.json' );
			} else {
				$skin_data = getSkinJsonToArray( UNISPHERE_CSS . '/skins/' . (is_multisite() && startsWith( $input['skin_current'], '_multisite_' ) ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/settings.json' );
			}
			$i = 0;
			for ( $i=0 ; $i<count($skin_data) ; $i++ ) {
				foreach ( $skin_data[$i] as $key => $value ) {
					if( is_array($value) && !empty($value['image']) ) {
						if( isset( $_POST['skin_create'] ) ) {
							$value['image'] = UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $new_skin_name . '/' . basename($value['image']);
						} else {
							$value['image'] = UNISPHERE_CSS . '/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/' . basename($value['image']);
						}
					}
					$input[$key] = $value;
					$skin_json_data[$key] = $value;
				}
			}
		}

		// If the portfolio detail page permalink is changed, flag it for WordPress permalink rewrite
		if( $location == THEME_OPTIONS_PAGE ) {
			update_option('flush_rewrite_rules', '1');
		}

		// Any changes to the Skins manager or Fonts manager pages deletes the cached data for the fonts
		if( $location == SKINS_MANAGER_PAGE || $location == FONTS_MANAGER_PAGE ) {
			delete_transient( UNISPHERE_THEMEOPTIONS . '-enqueue_google_fonts' );
			delete_transient( UNISPHERE_THEMEOPTIONS . '-enqueue_cufon_fonts' );
			delete_transient( UNISPHERE_THEMEOPTIONS . '-cufon_selectors' );
		}

		$images_to_copy = array();
		$images_to_delete = array();

		foreach ( $options as $option ) {

			if ( ! isset( $option['id'] ) ) {
				continue;
			}

			if ( ! isset( $option['type'] ) ) {
				continue;
			}

			$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );
			
			if ( isset( $option['location'] ) && $option['location'] == $location ) {

				// If in the SKINS page, copy the background images from the background fields to the skin folder
				if( $skin_update && isset( $option['type'] ) && $option['type'] == 'background' && isset( $input[$id]['image'] ) && $input[$id]['image'] != '' ) {
					if( contains( '/wp-content/uploads/', $input[$id]['image'] ) ) {
						$source_path = truepath(ABSPATH . '/wp-content/uploads') . substr( $input[$id]['image'], strpos( $input[$id]['image'], '/wp-content/uploads/' ) + 19 );
						$dest_filename = $id . '.' . end( explode( '.', $input[$id]['image']) );
						$dest_path = truepath( TEMPLATEPATH . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/' . $dest_filename );
						$dest_url = get_template_directory_uri() . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/' . $dest_filename;

						$images_to_copy[] = array('source_path' => $source_path, 'dest_path' => $dest_path, 'dest_url' => $dest_url, 'option_id' => $id );
					}

					if( contains( '/files/', $input[$id]['image'] ) && is_multisite() ) {
						$file_parts = explode('/files/', $input[$id]['image']);
						$source_path = truepath(ABSPATH . 'wp-content/blogs.dir/' . get_current_blog_id() . '/files/' . $file_parts[1]);
						$dest_filename = $id . '.' . end( explode( '.', $input[$id]['image']) );
						$dest_path = truepath( TEMPLATEPATH . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/' . $dest_filename );
						$dest_url = get_template_directory_uri() . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] . '/' . $dest_filename;

						$images_to_copy[] = array('source_path' => $source_path, 'dest_path' => $dest_path, 'dest_url' => $dest_url, 'option_id' => $id );
					}
				}

				// Try and delete image files that the user has removed
				if( $skin_update && isset( $option['type'] ) && $option['type'] == 'background' && empty($input[$id]['image']) ) {
					$file = truepath( TEMPLATEPATH . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] ) . '/' . $id . '.';
					if( file_exists( $file . 'jpg' ) ) {
						$images_to_delete[] = $file . 'jpg';
					} elseif( file_exists( $file . 'jpeg' ) ) {
						$images_to_delete[] = $file . 'jpeg';
					} elseif( file_exists( $file . 'png' ) ) {
						$images_to_delete[] = $file . 'png';
					} elseif( file_exists( $file . 'gif' ) ) {
						$images_to_delete[] = $file . 'gif';
					}
				}

				// Also delete the auto generated image for the sub-header background so that it gets re-generated at runtime
				if( $skin_update && isset( $option['type'] ) && $option['type'] == 'background' && $id == 'skin_sub_header_bar_bgimage' ) {
					$files = list_files( truepath( TEMPLATEPATH . '/css/skins/' . (is_multisite() ? '_multisite_' . get_current_blog_id() . '/' : '') . $input['skin_current'] ), 1 );
				    foreach ($files as $file ) {
						if( startsWith( basename($file), 'skin_sub_header_bar_bgimage-' ) ) {
							$images_to_delete[] = $file;
						}
					}
				}

				// Set checkbox to false if it wasn't sent in the $_POST
				if ( 'checkbox' == $option['type'] && ! isset( $input[$id] ) ) {
					$input[$id] = '0'; $clean[$id] = '0';
				}

				// Set each item in the multicheck to false if it wasn't sent in the $_POST
				if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
					foreach ( $option['options'] as $key => $value ) {
						$input[$id][$key] = '0';
					}
				}

				// For a value to be submitted to database it must pass through a sanitization filter
				if ( has_filter( 'of_sanitize_' . $option['type'] ) && !empty( $input[$id] ) ) {
					$clean[$id] = apply_filters( 'of_sanitize_' . $option['type'], $input[$id], $option );
				}

				if ( $option['type'] == 'text' && $input[$id] == '0' ) {
					$clean[$id] = '0';
				}

				// In case of current skin change or create, clear option values not present in the skin json file
				if ( isset( $_POST['skin_current'] ) && !isset( $_POST['skin_import'] ) && !isset( $skin_json_data[$id] ) ) {
					unset($clean[$id]);
				}

				// In case of a skin import clear all values so they get loaded in the next page load instead
				if ( isset( $_POST['skin_import'] ) ) {
					unset($clean[$id]);
				}

				if ( $id == 'skin_current' || $id == 'sidebar_list' ) {
					$clean[$id] = $input[$id];
				}
			} else {
				// Keep the other theme admin pages fields intact
				$option_value = of_get_option( $option['id'] );
				if( $option_value != '') {
					$clean[$id] = of_get_option( $option['id'] );
				}
			}

			// Always clean the import and export settings field as we don't want it to be stored in the database
			if( $id == "export_settings" || $id == "import_settings" ) {
				unset($clean[$id]);
			}
		}

		// The "Save options" button has been hit and this is the Skin Manager page
		if( $skin_update ) {
			// Flag this to perform some operations on the next page load
			update_option('unisphere_skin_update_' . $current_user->ID, array('images_to_copy' => $images_to_copy, 'images_to_delete' => $images_to_delete) );
		}

		if ( isset( $_POST['skin_current'] ) && !isset( $_POST['skin_create'] ) && !isset( $_POST['skin_delete'] ) && !isset( $_POST['skin_import'] ) ) {
			$clean['skin_current'] = $input['skin_current'];
			add_settings_error( 'options-framework', 'skin_current', __( 'Skin selection saved.', 'optionsframework' ), 'updated fade' );
			return $clean;
		}

		if ( isset( $_POST['skin_current'] ) && isset( $_POST['skin_create'] ) ) {
			$clean['skin_current'] = $input['skin_current'];
			add_settings_error( 'options-framework', 'skin_create', __( 'New skin created.', 'optionsframework' ), 'updated fade' );
			return $clean;
		}

		if ( isset( $_POST['skin_current'] ) && isset( $_POST['skin_delete'] ) ) {
			$clean['skin_current'] = $input['skin_current'];
			add_settings_error( 'options-framework', 'skin_delete', __( 'Skin deleted.', 'optionsframework' ), 'updated fade' );
			return $clean;
		}

		if( isset( $_POST['sidebar_create'] ) )
			add_settings_error( 'options-framework', 'sidebar_create', __( 'New custom sidebar created.', 'optionsframework' ), 'updated fade' );

		if( isset( $_POST['sidebar_delete'] ) )
			add_settings_error( 'options-framework', 'sidebar_delete', __( 'Custom sidebar deleted.', 'optionsframework' ), 'updated fade' );

		if( isset( $_POST['sidebar_exists'] ) )
			add_settings_error( 'options-framework', 'sidebar_exists', __( 'Error: there\'s already a sidebar with that name or the field is empty.', 'optionsframework' ), 'error' );

		if( isset( $_POST['fonts_update_google'] ) )
			add_settings_error( 'options-framework', 'fonts_update_google', __( 'Google web fonts list updated successfully.', 'optionsframework' ), 'updated fade' );

		if( !isset( $_POST['skin_import'] ) && !isset( $_POST['sidebar_create'] ) && !isset( $_POST['sidebar_delete'] ) && !isset( $_POST['sidebar_exists'] ) && !isset( $_POST['fonts_update_google'] ) )
			add_settings_error( 'options-framework', 'save_options', __( 'Options saved.', 'optionsframework' ), 'updated fade' );

		return $clean;
	}

	/*
	 * Request Not Recognized.
	 */
	
	return of_get_default_values( $location );
}

/**
 * Format Configuration Array.
 *
 * Get an array of all default values as set in
 * options.php. The 'id','std' and 'type' keys need
 * to be defined in the configuration array. In the
 * event that these keys are not present the option
 * will not be included in this function's output.
 *
 * @return    array     Rey-keyed options configuration array.
 *
 * @access    private
 */
 
function of_get_default_values( $location ) {
	$output = array();
	$config = optionsframework_options();
	foreach ( (array) $config as $option ) {
		if ( ! isset( $option['id'] ) ) {
			continue;
		}
		if ( ! isset( $option['std'] ) ) {
			continue;
		}
		if ( ! isset( $option['type'] ) ) {
			continue;
		}
		if ( isset( $option['location'] ) && $option['location'] == $location ) {
			if ( has_filter( 'of_sanitize_' . $option['type'] ) ) {
				$output[$option['id']] = apply_filters( 'of_sanitize_' . $option['type'], $option['std'], $option );
			} elseif( $option['type'] == 'skin_current' ) {
				$output[$option['id']] = $option['std'];
			}
		} else {
			// Keep the other theme admin pages fields intact
			$output[$option['id']] = of_get_option( $option['id'] );
		}
	}
	return $output;
}

/**
 * Add Theme Options menu item to Admin Bar.
 */
 
add_action( 'wp_before_admin_bar_render', 'optionsframework_adminbar' );

function optionsframework_adminbar() {
	
	global $wp_admin_bar;
	
	$wp_admin_bar->add_menu( array(
		'parent' => 'appearance',
		'id' => 'of_theme_options',
		'title' => __( 'Theme Options', 'optionsframework' ),
		'href' => admin_url( 'themes.php?page=options-framework' )
  ));
}

if ( ! function_exists( 'of_get_option' ) ) {

	/**
	 * Get Option.
	 *
	 * Helper function to return the theme option value.
	 * If no value has been saved, it returns $default.
	 * Needed because options are saved as serialized strings.
	 */
	 
	function of_get_option( $name, $default = false ) {
		$config = get_option( 'optionsframework' );

		if ( ! isset( $config['id'] ) ) {
			return $default;
		}

		$options = get_option( $config['id'] );

		if ( isset( $options[$name] ) ) {
			return $options[$name];
		}

		return $default;
	}
}

if ( ! function_exists( 'of_update_option' ) ) {
	function of_update_option( $name, $value, $array = '' ) {
		$config = get_option( 'optionsframework' );

		if ( ! isset( $config['id'] ) ) {
			return false;
		}

		$options = get_option( $config['id'] );

		if( $array != '' ) {
			$options[$name][$array] = $value;
		} else {
			$options[$name] = $value;
		}

		if( $value == '' ) {
			unset($options[$name]);
		}

		$optionsframework_settings = get_option('optionsframework' );
		
		// Updates the unique option id in the database if it has changed
		optionsframework_option_name();
		
		// Gets the unique id, returning a default if it isn't defined
		if ( isset($optionsframework_settings['id']) ) {
			$option_name = $optionsframework_settings['id'];
		}
		else {
			$option_name = 'optionsframework';
		}
		
		unregister_setting( 'optionsframework', $option_name, 'optionsframework_validate' );
		update_option( $config['id'], $options );
		unregister_setting( 'optionsframework', $option_name, 'optionsframework_validate' );

		$options = get_option( $config['id'] );
	}
}


/**
 * Zip and force download the files using PHP
 */
function zipFolderAndDownload( $folder )
{	
	$dest_file_name = str_replace( '_theme_', '', of_get_option('skin_current') . '_' . date("Ymdgi") . '.zip' );
	$temp_file_name = truepath(TEMPLATEPATH . '/../../uploads') . '/' . $dest_file_name;

	// Send the headers to force download the zip file
	header("Content-type: application/zip");
	header("Content-Disposition: inline; filename=$dest_file_name");
	header("Pragma: no-cache");
	header("Expires: 0");
	
	if ( class_exists('ZipArchive') ) {
		//create the zip object
		$zip = new ZipArchive();

		//create the file and throw the error if unsuccessful
		$zip->open($temp_file_name, ZIPARCHIVE::CREATE );

	    $files = list_files( $folder, 1 );
	    foreach ($files as $file ) {
	    	$file = basename($file);
			// if it isn't this folder or its parent, add it to the results
			if ( !startsWith( $file, '.' ) ) {
				//add each file to the zip archive
				$zip->addFile( $folder . '/' . $file, $file );
			}
		}
		$zip->close();

		readfile("$temp_file_name");

		// Delete the temp file
		unlink( $temp_file_name );
		exit;
	} 

	// Fall through to PclZip if ZipArchive is not available, or encountered an error opening the file.
	require_once(ABSPATH . 'wp-admin/includes/class-pclzip.php');

	$zip = new PclZip($temp_file_name);	
	$files = list_files( $folder, 1 );
	$zip->add( $files, PCLZIP_OPT_REMOVE_PATH, $folder . '/' );
	
	readfile("$temp_file_name");

	// Delete the temp file
	unlink( $temp_file_name );
	exit;
} 

/**
 * Unzip skin file and copy contents to skins folder
 */
function unzipSkinFile( $zip_file, $new_skin_name ) {
	global $wp_filesystem;

	$new_skin_path = truepath( TEMPLATEPATH . '/css/skins/' . $new_skin_name );

	if( is_multisite() )
		$new_skin_path = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $new_skin_name );

	// Unzip's a specified ZIP file to a location on the Filesystem via the WordPress Filesystem Abstraction.
 	// Assumes that WP_Filesystem() has already been called and set up. Does not extract a root-level __MACOSX directory, if present.
	return unzip_file( $zip_file, $new_skin_path );
}

/**
 * Create a backup of the specified skin outside of the theme folder
 */
function createSkinBackup( $skin ) {
	global $wp_filesystem;

	// Check if the backups folder exists and create it if not	
	if ( !$wp_filesystem->mkdir(UNISPHERE_BACKUPS_PATH, FS_CHMOD_DIR) && !$wp_filesystem->is_dir(UNISPHERE_BACKUPS_PATH) ) { 
		// if there's an error return and do nothing, let the script execute normally
		return false;
	}

	// Check if the 'skins' folder inside the backups folder exists and create it if not	
	if ( !$wp_filesystem->mkdir(UNISPHERE_BACKUPS_PATH . '/skins', FS_CHMOD_DIR) && !$wp_filesystem->is_dir(UNISPHERE_BACKUPS_PATH . '/skins') ) { 
		// if there's an error return and do nothing, let the script execute normally
		return false;
	}

	if( is_multisite() ) {
		// Check if the '_multisite_X' folder exists and create it if not	
		if ( !$wp_filesystem->mkdir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id()), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id()) ) ) { 
			// if there's an error return and do nothing, let the script execute normally
			return false;
		}

		// Check if the specified skin backup folder exists and create it if not	
		if ( !$wp_filesystem->mkdir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin) ) ) { 
			// if there's an error return and do nothing, let the script execute normally
			return false;
		}

		// copy the contents of the specified skin folder to the backup folder
		copy_dir( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $skin ), truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin) );
	} else {
		// Check if the specified skin backup folder exists and create it if not	
		if ( !$wp_filesystem->mkdir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/' . $skin), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/' . $skin) ) ) { 
			// if there's an error return and do nothing, let the script execute normally
			return false;
		}

		// copy the contents of the specified skin folder to the backup folder
		copy_dir( truepath( TEMPLATEPATH . '/css/skins/' . $skin ), truepath(UNISPHERE_BACKUPS_PATH . '/skins/' . $skin) );
	}
}

/**
 * Delete a backup of the specified skin
 */
function deleteSkinBackup( $skin ) {
	global $wp_filesystem;

	if( is_multisite() ) {
		if ( $wp_filesystem->is_dir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin ) ) )
			$wp_filesystem->delete( truepath(UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin ), true);
	} else {
		if ( $wp_filesystem->is_dir( truepath(UNISPHERE_BACKUPS_PATH . '/skins/' . $skin ) ) )
			$wp_filesystem->delete( truepath(UNISPHERE_BACKUPS_PATH . '/skins/' . $skin ), true);
	}
}

/**
 * Create a backup of the specified font file outside of the theme folder
 */
function createFontBackup( $font_path ) {
	global $wp_filesystem;

	// Check if the backups folder exists and create it if not	
	if ( !$wp_filesystem->mkdir(UNISPHERE_BACKUPS_PATH, FS_CHMOD_DIR) && !$wp_filesystem->is_dir(UNISPHERE_BACKUPS_PATH) ) { 
		// if there's an error return and do nothing, let the script execute normally
		return false;
	}

	// Check if the 'fonts' folder inside the backups folder exists and create it if not	
	if ( !$wp_filesystem->mkdir(UNISPHERE_BACKUPS_PATH . '/fonts', FS_CHMOD_DIR) && !$wp_filesystem->is_dir(UNISPHERE_BACKUPS_PATH . '/fonts') ) { 
		// if there's an error return and do nothing, let the script execute normally
		return false;
	}

	// copy the font to the backup folder
	$dest_path = truepath( UNISPHERE_BACKUPS_PATH . '/fonts/' . end( explode( '/', str_replace('\\', '/', $font_path))));
	$wp_filesystem->copy($font_path, $dest_path);
}

/**
 * Asks user if he wants to restore skin and font backups that are not present on the theme skins folder
 */
function restoreBackups() {	
	global $current_location;
	$theme_data = unisphere_wp_get_theme();
	$chosen_option = '';

	if ( isset($_REQUEST['action']) && $_REQUEST['action'] == 'restore_backups' ) {
		if( wp_verify_nonce($_REQUEST['_wpnonce'], 'restore_backups_' . $theme_data['Version']) ) {
			$chosen_option = '1';
		}
	}

	if ( isset($_REQUEST['action']) && $_REQUEST['action'] == 'ignore_backups' ) {
		if( wp_verify_nonce($_REQUEST['_wpnonce'], 'ignore_backups_' . $theme_data['Version']) ) {
			$chosen_option = '2';
		}
	}

	if( $chosen_option != '' )
		update_option('unisphere_backups_' . $theme_data['Version'], $chosen_option);
	
	// 0 = show notification
	// 1 = synchronize
	// 2 = don't show the notification more in this theme version
	$restore_option = get_option('unisphere_backups_' . $theme_data['Version']);
	
	if( $restore_option != '2' ) {
		if( $restore_option == '' ) {
			// Check if there are any skin backups to restore
			$skin_backup_available = false;	

			// Get installed skins from the theme skins folder
			$installed_skins = array();
			$folders = list_files( truepath( TEMPLATEPATH . '/css/skins' ), 1 );
		    foreach ($folders as $folder ) {
		    	$folder = basename($folder);
				// if it isn't this folder or its parent, or a default skin...
				if ( !startsWith( $folder, '.' ) && !startsWith( $folder, '_theme_') && !startsWith( $folder, '_multisite_' ) ) {
					$installed_skins[] = $folder;
				}

				// See if it's a multisite skin
				if ( $folder == '_multisite_' . get_current_blog_id() ) {
					$multisite_folders = list_files( truepath( TEMPLATEPATH . '/css/skins/' . $folder ), 1 );
					foreach ($multisite_folders as $multisite_folder ) {
						$multisite_folder = basename($multisite_folder);
						// if it isn't this folder or its parent, add it to the results
						if ( !startsWith( $multisite_folder, '.' ) ) {
							$installed_skins[] = $multisite_folder;
						}
					}
				}
			}

			// Get backup skins from the backup skins folder
			$backup_skins = array();
			$folders = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/skins' ), 1 );
		    foreach ($folders as $folder ) {
		    	$folder = basename($folder);
				// if it isn't this folder or its parent, or a default skin...
				if ( !startsWith( $folder, '.' ) && !startsWith( $folder, '_theme_') && !startsWith( $folder, '_multisite_' ) ) {
					$backup_skins[] = $folder;
				}

				// See if it's a multisite skin
				if ( $folder == '_multisite_' . get_current_blog_id() ) {
					$multisite_folders = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/skins/' . $folder ), 1 );
					foreach ($multisite_folders as $multisite_folder ) {
						$multisite_folder = basename($multisite_folder);
						// if it isn't this folder or its parent, add it to the results
						if ( !startsWith( $multisite_folder, '.' ) ) {
							$backup_skins[] = $multisite_folder;
						}
					}
				}
			}

			if( count(array_diff($backup_skins, $installed_skins)) > 0 )
				$skin_backup_available = true;
			
			// Check if there are any font backups to restore
			$font_backup_available = false;	

			// Get installed fonts from the theme fonts folder
			$installed_fonts = array();
			$files = list_files( truepath( TEMPLATEPATH . '/fonts' ), 1 );
		    foreach ($files as $file ) {
		    	$file = basename($file);
				// if it isn't this folder or its parent...
				if ( !startsWith( $file, '.' ) && ( !startsWith( $file, '_multisite_' ) || startsWith( $file, '_multisite_' . get_current_blog_id() ) ) ) {
					$installed_fonts[] = $file;
				}
			}

			// Get backup fonts from the backup fonts file
			$backup_fonts = array();
			$files = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/fonts' ), 1 );
		    foreach ($files as $file ) {
		    	$file = basename($file);
				// if it isn't this folder or its parent...
				if ( !startsWith( $file, '.' ) && ( !startsWith( $file, '_multisite_' ) || startsWith( $file, '_multisite_' . get_current_blog_id() ) ) ) {
					$backup_fonts[] = $file;
				}
			}

			if( count(array_diff($backup_fonts, $installed_fonts)) > 0 )
				$font_backup_available = true;

			if( $skin_backup_available || $font_backup_available )
				$restore_option = '0'; // show restore notification
			else
				$restore_option = '2'; // ignore and don't ask again in this theme version

			update_option('unisphere_backups_' . $theme_data['Version'], $restore_option);
		}

		// Show notification
		if( $restore_option == '0' ) {
			$restore_link_nonce = wp_create_nonce('restore_backups_' . $theme_data['Version']);
			$ignore_link_nonce = wp_create_nonce('ignore_backups_' . $theme_data['Version']);
			echo '<div class="error"><p>';
			echo 'The theme has detected that a theme update was installed and found <strong>Skins</strong> and/or <strong>Fonts</strong> that are on the <strong><u>BACKUP</u></strong> folder.<br />';
			echo 'Actions:&nbsp;&nbsp;<a href="admin.php?page=options-framework-skins-manager&amp;action=restore_backups&amp;_wpnonce=' . $restore_link_nonce . '">Restore backups</a>&nbsp;&nbsp;|&nbsp;&nbsp;<a href="admin.php?page=options-framework-skins-manager&amp;action=ignore_backups&amp;_wpnonce=' . $ignore_link_nonce . '">Ignore and don\'t warn me again</a>';
			echo '</p></div>';
		}

		// Restore Backups
		if( $restore_option == '1' ) {
			if( unisphere_check_credentials( $current_location ) ) {
				global $wp_filesystem;

				// Get installed skins from the theme skins folder
				$installed_skins = array();
				$folders = list_files( truepath( TEMPLATEPATH . '/css/skins' ), 1 );
			    foreach ($folders as $folder ) {
			    	$folder = basename($folder);
					// if it isn't this folder or its parent, or a default skin...
					if ( !startsWith( $folder, '.' ) && !startsWith( $folder, '_theme_') && !startsWith( $folder, '_multisite_' ) ) {
						$installed_skins[] = $folder;
					}

					// See if it's a multisite skin
					if ( $folder == '_multisite_' . get_current_blog_id() ) {
						$multisite_folders = list_files( truepath( TEMPLATEPATH . '/css/skins/' . $folder ), 1 );
						foreach ($multisite_folders as $multisite_folder ) {
							$multisite_folder = basename($multisite_folder);
							// if it isn't this folder or its parent, add it to the results
							if ( !startsWith( $multisite_folder, '.' ) ) {
								$installed_skins[] = $multisite_folder;
							}
						}
					}
				}

				// Get backup skins from the backup skins folder
				$backup_skins = array();
				$folders = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/skins' ), 1 );
			    foreach ($folders as $folder ) {
			    	$folder = basename($folder);
					// if it isn't this folder or its parent, or a default skin...
					if ( !startsWith( $folder, '.' ) && !startsWith( $folder, '_theme_') && !startsWith( $folder, '_multisite_' ) ) {
						$backup_skins[] = $folder;
					}

					// See if it's a multisite skin
					if ( $folder == '_multisite_' . get_current_blog_id() ) {
						$multisite_folders = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/skins/' . $folder ), 1 );
						foreach ($multisite_folders as $multisite_folder ) {
							$multisite_folder = basename($multisite_folder);
							// if it isn't this folder or its parent, add it to the results
							if ( !startsWith( $multisite_folder, '.' ) ) {
								$backup_skins[] = $multisite_folder;
							}
						}
					}
				}

				$skins_to_restore = array_diff($backup_skins, $installed_skins);

				$restored = true;
				foreach($skins_to_restore as $skin_to_restore) {
					if( is_multisite() ) {
						$source_path = truepath( UNISPHERE_BACKUPS_PATH . '/skins/_multisite_' . get_current_blog_id() . '/' . $skin_to_restore );
						$dest_path = truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() . '/' . $skin_to_restore );
					} else {
						$source_path = truepath( UNISPHERE_BACKUPS_PATH . '/skins/' . $skin_to_restore );
						$dest_path = truepath( TEMPLATEPATH . '/css/skins/' . $skin_to_restore );
					}
					// If is multisite check if the /skins/site_id/ folder is created
					if( is_multisite() ) {
						if ( !$wp_filesystem->mkdir(truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id()), FS_CHMOD_DIR) && !$wp_filesystem->is_dir( truepath( TEMPLATEPATH . '/css/skins/_multisite_' . get_current_blog_id() ) ) ) { // Only check to see if the Dir exists upon creation failure. Less I/O this way.
							$restored = false;
							break;
						}
					}
					//Create destination if needed
					if ( !$wp_filesystem->exists($dest_path) ) {
						if ( !$wp_filesystem->mkdir($dest_path, FS_CHMOD_DIR) ) {
							$restored = false;
							break;
						}
					}

					// Copy backup into place.
					$result = copy_dir($source_path, $dest_path);
					if ( is_wp_error($result) ) {
						$restored = false;
						break;
					}
				}

				// Get installed fonts from the theme fonts folder ------------------------------
				$installed_fonts = array();
				$files = list_files( truepath( TEMPLATEPATH . '/fonts' ), 1 );
			    foreach ($files as $file ) {
			    	$file = basename($file);
					// if it isn't this folder or its parent
					if ( !startsWith( $file, '.' ) && ( !startsWith( $file, '_multisite_' ) || startsWith( $file, '_multisite_' . get_current_blog_id() ) ) ) {					
						$installed_fonts[] = $file;
					}
				}

				// Get backup fonts from the backup fonts file
				$backup_fonts = array();
				$files = list_files( truepath( UNISPHERE_BACKUPS_PATH . '/fonts' ), 1 );
			    foreach ($files as $file ) {
			    	$file = basename($file);
					// if it isn't this folder or its parent
					if ( !startsWith( $file, '.' ) && ( !startsWith( $file, '_multisite_' ) || startsWith( $file, '_multisite_' . get_current_blog_id() ) ) ) {
						$backup_fonts[] = $file;
					}
				}

				$fonts_to_restore = array_diff($backup_fonts, $installed_fonts);

				foreach($fonts_to_restore as $font_to_restore) {
					$source_path = truepath( UNISPHERE_BACKUPS_PATH . '/fonts/' . $font_to_restore );
					$dest_path = truepath( TEMPLATEPATH . '/fonts/' . $font_to_restore );

					// Copy file
					if( !$wp_filesystem->copy($source_path, $dest_path, true, FS_CHMOD_FILE ) ) {
						$restored = false;
						break;
					}
				}	
			}

			if( $restored ) {				
				$restore_option = '2'; // don't ask again in this theme version
				update_option('unisphere_backups_' . $theme_data['Version'], $restore_option);
				delete_transient('cufon_fonts');
				wp_redirect( self_admin_url('admin.php?page=options-framework-skins-manager') );
				exit;
			} else {
				$restore_option = '0'; // display the notification again 
				update_option('unisphere_backups_' . $theme_data['Version'], $restore_option);
				wp_die('Could not restore backup. Please check file/folder permissions and/or ownership.');
			}
		}
	}
}

/**
 * Read skin JSON file and copy it to DB
 */
function getSkinJsonToArray( $file ) {
	$response = wp_remote_get( $file );
	if( is_wp_error( $response ) || $response['response']['code'] != 200 ) {
		// Let's try an alternate approach		
		$filename = truepath( TEMPLATEPATH . '/css/skins/' . substr( $file, strpos( $file, '/skins/' ) + 7 ) );
		if ($fh = fopen($filename, "r")) {
			$file_content = fread($fh, filesize($filename));
			$json_data = json_decode( $file_content, true );	
			if($json_data == '' || !$json_data) {
				fclose($fh);
				wp_die("Something went wrong opening the skin &lt;" . $file . "> file.");
			}
			fclose($fh);
			return $json_data;
		}	   	
	} else {
		// Parse the JSON data into a PHP array
		$json_data = json_decode( $response['body'], true );	
		return $json_data;
	}
}

/**
 * This function is to replace PHP's extremely buggy realpath().
 */
function truepath($path){
    // whether $path is unix or not
    $unipath=strlen($path)==0 || $path{0}!='/';
    // attempts to detect if path is relative in which case, add cwd
    if(strpos($path,':')===false && $unipath)
        $path=getcwd().DIRECTORY_SEPARATOR.$path;
    // resolve path parts (single dot, double dot and double delimiters)
    $path = str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $path);
    $parts = array_filter(explode(DIRECTORY_SEPARATOR, $path), 'strlen');
    $absolutes = array();
    foreach ($parts as $part) {
        if ('.'  == $part) continue;
        if ('..' == $part) {
            array_pop($absolutes);
        } else {
            $absolutes[] = $part;
        }
    }
    $path=implode(DIRECTORY_SEPARATOR, $absolutes);
    // resolve any symlinks
    if( function_exists('readlink') ) {
    	if(file_exists($path) && linkinfo($path)>0)$path=readlink($path);
    }
    // put initial separator that could have been lost
    $path=!$unipath ? '/'.$path : $path;
    return $path;
}
