<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */
function optionsframework_option_name() {

	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = UNISPHERE_THEMEOPTIONS;
	update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */
function optionsframework_options() {
	
	// Background options
	$background_options = array( "transparent" => "Transparent", "dark" => "Dark", "light" => "Light", "solid" => "Solid color" );

	// Background options without the "transparent" option
	$background_options_no_transparent = array( "dark" => "Dark", "light" => "Light", "solid" => "Solid color" );

	// Some buttons background options
	$button_background_options = array( "black" => "Black", "white" => "White" );

	// Background Defaults	
	$background_defaults = array( 'image' => '', 'repeat' => 'repeat', 'position' => 'top center', 'attachment'=>'scroll' );

	// Font subsets defaults
	$font_subsets_defaults = array( 'cyrillic' => 'Cyrillic', 'cyrillic-ext' => 'Cyrillic Extended', 'greek' => 'Greek', 'greek-ext' => 'Greek Extended', 'latin' => 'Latin', 'latin-ext' => 'Latin Extended', 'vietnamese' => 'Vietnamese' );

	// Font styles defaults
	$font_styles_defaults = array(  '100' => 'Ultra-Light 100',
									'100italic' => 'Ultra-Light 100 Italic',
									'200' => 'Light 200',
									'200italic' => 'Light 200 Italic',
									'300' => 'Book 300',
									'300italic' => 'Book 300 Italic',
									'400' => 'Normal 400',
									'400italic' => 'Normal 400 Italic',
									'500' => 'Medium 500',
									'500italic' => 'Medium 500 Italic',
									'600' => 'Semi-Bold 600',
									'600italic' => 'Semi-Bold 600 Italic',
									'700' => 'Bold 700',
									'700italic' => 'Bold 700 Italic',
									'800' => 'Extra-Bold 800',
									'800italic' => 'Extra-Bold 800 Italic',
									'900' => 'Ultra-Bold 900',
									'900italic' => 'Ultra-Bold 900 Italic' );

	$optionsframework_settings = get_option('optionsframework' );
	
	// Updates the unique option id in the database if it has changed
	optionsframework_option_name();
	
	$export_settings = base64_encode(serialize(get_option($optionsframework_settings['id'])));

	// Cufon fonts in the /fonts/ folder
	$cufon_fonts = getCufonFonts();

	// Google Web Fonts list
	$google_fonts = getGoogleFonts(false);

	$options = array();
	
	// GENERAL -------------------------------------------------------------------
	$options[] = array( "name" => "General",
						"type" => "heading",
						"location" => THEME_OPTIONS_PAGE);
						
		$options[] = array( "name" => "Logo",
							"desc" => "Set your header logo image here.",
							"id" => "logo",
							"type" => "upload",
							"std" => "",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Favicon",
							"desc" => "Set your favicon here.",
							"id" => "favicon",
							"type" => "upload",
							"std" => "",
							"location" => THEME_OPTIONS_PAGE);
				
		$options[] = array( "name" => "Custom CSS",
							"desc" => "Add your custom css entries here.",
							"id" => "custom_css",
							"std" => "",
							"type" => "textarea",
							"location" => THEME_OPTIONS_PAGE); 
							
		$options[] = array( "name" => "Custom Scripts",
							"desc" => "Add your custom scripts here like for example your Google Analytics code to track your visitors.",
							"id" => "custom_js",
							"std" => "",
							"type" => "textarea",
							"location" => THEME_OPTIONS_PAGE); 

	// HEADER -------------------------------------------------------------------
	$options[] = array( "name" => "Header",
						"type" => "heading",
						"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show search field in the header menu?",
							"desc" => "Check this if you want to show the search field in the header navigation menu.",
							"id" => "show_search",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Use the header menu search field to display Woocommerce products?",
							"desc" => "Check this if you want the header menu search field display Woocommerce product results intead of the normal pages/posts.",
							"id" => "menu_search_products",
							"std" => "0",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

	// BLOG -------------------------------------------------------------------
	$options[] = array( "name" => "Blog",
						"type" => "heading",
						"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Blog template displayed in the Archives",
							"desc" => "Select the blog template displayed in the categories, tags, author and date archives.",
							"id" => "skin_blog_archives_template",
							"std" => "template_blog.php",
							"type" => "select",
							"class" => "mini",
							"options" => array( "template_blog.php" => "Default Template", "template_blog_alternate.php" => "Alternate Template", "template_blog_masonry.php" => "Masonry Template" ),
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show \"Next\" and \"Previous\" navigation links on post detail?",
							"desc" => "Check this if you want to show the \"Next\" and \"Previous\" links on the post detail page.",
							"id" => "show_post_navigation_links",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the \"Tweet\" button?",
							"desc" => "Check this if you want to show the \"Tweet\" button on the blog posts.",
							"id" => "show_blog_tweet_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Facebook \"Like\" button?",
							"desc" => "Check this if you want to show the Facebook \"Like\" button on the blog posts.",
							"id" => "show_blog_fb_like_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the \"Google Plus\" button?",
							"desc" => "Check this if you want to show the \"Google Plus\" button on the blog posts.",
							"id" => "show_blog_google_plus_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Author?",
							"desc" => "Check this if you want to show the Author meta information on blog posts.",
							"id" => "show_meta_author",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Date?",
							"desc" => "Check this if you want to show the Date meta information on blog posts.",
							"id" => "show_meta_date",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Categories?",
							"desc" => "Check this if you want to show the Categories meta information on blog posts.",
							"id" => "show_meta_categories",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);
		
		$options[] = array( "name" => "Show the Tags?",
							"desc" => "Check this if you want to show the Tags meta information on blog posts.",
							"id" => "show_meta_tags",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);
		
		$options[] = array( "name" => "Show the Comment Count?",
							"desc" => "Check this if you want to show the Comment Count meta information on blog posts.",
							"id" => "show_meta_comment_count",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Author Info section?",
							"desc" => "Check this if you want to show the Author Info section on the blog post detail page.",
							"id" => "show_blog_author_info",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Related Posts section?",
							"desc" => "Check this if you want to show the Related Posts section on the blog post detail page.",
							"id" => "show_blog_related_posts",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

	// PORTFOLIO -------------------------------------------------------------------
	$options[] = array( "name" => "Portfolio",
						"type" => "heading",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Portfolio Detail Page Permalink",
							"desc" => "This is the portfolio detail page permalink if using custom permalink settings in WordPress.",
							"id" => "portfolio_permalink",
							"std" => "portfolio/detail",
							"type" => "text",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show \"Next\" and \"Previous\" navigation links on portfolio detail?",
							"desc" => "Check this if you want to show the \"Next\" and \"Previous\" links on the portfolio item detail page.",
							"id" => "show_portfolio_navigation_links",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the \"Tweet\" button?",
							"desc" => "Check this if you want to show the \"Tweet\" button on the portfolio item detail page.",
							"id" => "show_portfolio_tweet_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Facebook \"Like\" button?",
							"desc" => "Check this if you want to show the Facebook \"Like\" button on the portfolio item detail page.",
							"id" => "show_portfolio_fb_like_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the \"Google Plus\" button?",
							"desc" => "Check this if you want to show the \"Google Plus\" button on the portfolio item detail page.",
							"id" => "show_portfolio_google_plus_button",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Date?",
							"desc" => "Check this if you want to show the Date meta information on the portfolio item detail page.",
							"id" => "show_portfolio_meta_date",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Comment Count?",
							"desc" => "Check this if you want to show the Comment Count meta information on the portfolio item detail page.",
							"id" => "show_portfolio_meta_comment_count",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Show the Related Work section?",
							"desc" => "Check this if you want to show the Related Work section on the portfolio item detail page.",
							"id" => "show_portfolio_related_work",
							"std" => "1",
							"type" => "checkbox",
							"location" => THEME_OPTIONS_PAGE);

	// CONTACT -------------------------------------------------------------------
	$options[] = array( "name" => "Contact",
						"type" => "heading",
						"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Destination E-mail",
							"desc" => "This is the e-mail account you want your messages to be sent to.",
							"id" => "destination_email",
							"std" => "",
							"type" => "text",
							"location" => THEME_OPTIONS_PAGE);

		$options[] = array( "name" => "Success Message",
							"desc" => "This is the message displayed when someone uses the contact form and the email is sent successfully.",
							"id" => "email_success",
							"std" => "<strong>Thanks!</strong> Your email was successfully sent. I check my email all the time, so I should be in touch soon.",
							"type" => "text",
							"location" => THEME_OPTIONS_PAGE);
							
		$options[] = array( "name" => "Error Message",
							"desc" => "This is the message displayed when someone uses the contact form and an error occurs when sending the email.",
							"id" => "email_error",
							"std" => "<strong>There was an error sending your message.</strong> Please try again later.",
							"type" => "text",
							"location" => THEME_OPTIONS_PAGE);

	if( class_exists('Woocommerce') ) {

		// WOOCOMMERCE -------------------------------------------------------------------
		$options[] = array( "name" => "Woocommerce",
							"type" => "heading",
								"location" => THEME_OPTIONS_PAGE);

			$options[] = array( "name" => "Show \"Next\" and \"Previous\" navigation links on product detail?",
								"desc" => "Check this if you want to show the \"Next\" and \"Previous\" links on the product detail page.",
								"id" => "show_woocommerce_navigation_links",
								"std" => "1",
								"type" => "checkbox",
								"location" => THEME_OPTIONS_PAGE);

			$options[] = array( "name" => "Show the \"Tweet\" button?",
								"desc" => "Check this if you want to show the \"Tweet\" button on the product detail page.",
								"id" => "show_woocommerce_tweet_button",
								"std" => "1",
								"type" => "checkbox",
								"location" => THEME_OPTIONS_PAGE);

			$options[] = array( "name" => "Show the Facebook \"Like\" button?",
								"desc" => "Check this if you want to show the Facebook \"Like\" button on the product detail page.",
								"id" => "show_woocommerce_fb_like_button",
								"std" => "1",
								"type" => "checkbox",
								"location" => THEME_OPTIONS_PAGE);

			$options[] = array( "name" => "Show the \"Google Plus\" button?",
								"desc" => "Check this if you want to show the \"Google Plus\" button on the product detail page.",
								"id" => "show_woocommerce_google_plus_button",
								"std" => "1",
								"type" => "checkbox",
								"location" => THEME_OPTIONS_PAGE);
	}

	// IMPORT/EXPORT -------------------------------------------------------------------
	$options[] = array( "name" => "Import/Export",
						"type" => "heading",
						"location" => THEME_OPTIONS_PAGE);
						
		$options[] = array( "name" => "Import Settings",
							"desc" => "Paste an exported encoded field from another theme installation into this field in order to import the other theme installation settings. <strong>Note that the Skins and uploaded Fonts are not imported in this process, they have to be imported manually.</strong>",
							"id" => "import_settings",
							"std" => "",
							"type" => "textarea",
							"location" => THEME_OPTIONS_PAGE); 

		$options[] = array( "name" => "Export Settings",
							"desc" => "Copy this encoded field into the \"Import Settings\" field in another theme installation to import this installation settings. <strong>Note that the Skins and uploaded Fonts are not exported in this process.</strong>",
							"id" => "export_settings",
							"std" => $export_settings,
							"type" => "textarea",
							"location" => THEME_OPTIONS_PAGE); 

	// IMAGE SIZES -------------------------------------------------------------------
	$options[] = array( "name" => "",
						"type" => "heading",
						"location" => IMAGE_SIZES_PAGE);

		// sub-header slider
		$options[] = array( "name" => "Sub-header slider",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Notice",
								"desc" => "The sub-header slider image height is controlled by the sub-header slider height defined in the <a href='admin.php?page=options-framework-skins-manager'>Skins Manager</a> under \"Other Settings\"",
								"type" => "info",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_sub_header_slider_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// sub-header full width slider
		$options[] = array( "name" => "Sub-header full width slider",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Notice",
								"desc" => "The sub-header slider image height is controlled by the sub-header full width slider height defined in the <a href='admin.php?page=options-framework-skins-manager'>Skins Manager</a> under \"Other Settings\"",
								"type" => "info",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_sub_header_full_width_slider_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// sub-header bar
		$options[] = array( "name" => "Sub-header bar",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Notice",
								"desc" => "The sub-header bar image height is controlled by the sub-header bar height defined in the <a href='admin.php?page=options-framework-skins-manager'>Skins Manager</a> under \"Other Settings\"",
								"type" => "info",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_sub_header_bar_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 1 column portfolio
		$options[] = array( "name" => "1 column portfolio",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_1_column_portfolio_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_1_column_portfolio_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 1 column portfolio with sidebar
		$options[] = array( "name" => "1 column portfolio with sidebar",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_1_column_portfolio_with_sidebar_height",
								"std" => "200",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_1_column_portfolio_with_sidebar_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 2 column portfolio
		$options[] = array( "name" => "2 column portfolio",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_height",
								"std" => "480",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 2 column portfolio with sidebar
		$options[] = array( "name" => "2 column portfolio with sidebar",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_sidebar_height",
								"std" => "355",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_sidebar_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 2 column portfolio with description
		$options[] = array( "name" => "2 column portfolio with description",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_description_height",
								"std" => "465",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_description_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 2 column portfolio with sidebar and description
		$options[] = array( "name" => "2 column portfolio with sidebar and description",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_sidebar_and_description_height",
								"std" => "340",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_2_column_portfolio_with_sidebar_and_description_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 3 column portfolio
		$options[] = array( "name" => "3 column portfolio",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_height",
								"std" => "320",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 3 column portfolio with sidebar
		$options[] = array( "name" => "3 column portfolio with sidebar",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_sidebar_height",
								"std" => "236",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_sidebar_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 3 column portfolio with description
		$options[] = array( "name" => "3 column portfolio with description",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_description_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_description_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 3 column portfolio with sidebar and description
		$options[] = array( "name" => "3 column portfolio with sidebar and description",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_sidebar_and_description_height",
								"std" => "216",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_3_column_portfolio_with_sidebar_and_description_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 4 column portfolio
		$options[] = array( "name" => "4 column portfolio",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_4_column_portfolio_height",
								"std" => "240",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_4_column_portfolio_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 4 column portfolio with description
		$options[] = array( "name" => "4 column portfolio with description",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_4_column_portfolio_with_description_height",
								"std" => "216",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_4_column_portfolio_with_description_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// 5 column portfolio
		$options[] = array( "name" => "5 column portfolio",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_5_column_portfolio_height",
								"std" => "192",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_5_column_portfolio_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// portfolio detail big images
		$options[] = array( "name" => "Portfolio detail big images",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_portfolio_detail_big_images_height",
								"std" => "9999",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_portfolio_detail_big_images_crop",
								"std" => "0",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog
		$options[] = array( "name" => "Blog",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog (without sidebar)
		$options[] = array( "name" => "Blog (without sidebar)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_without_sidebar_height",
								"std" => "400",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_without_sidebar_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog (alternate style)
		$options[] = array( "name" => "Blog (alternate style)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_alternate_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_alternate_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog (alternate style without sidebar)
		$options[] = array( "name" => "Blog (alternate style without sidebar)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_alternate_without_sidebar_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_alternate_without_sidebar_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog (masonry)
		$options[] = array( "name" => "Blog (masonry)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_full_width_height",
								"std" => "9999",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_full_width_crop",
								"std" => "0",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog detail
		$options[] = array( "name" => "Blog detail",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_detail_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_detail_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// blog detail (without sidebar)
		$options[] = array( "name" => "Blog detail (without sidebar)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_blog_detail_without_sidebar_height",
								"std" => "300",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_blog_detail_without_sidebar_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// sidebar posts (recent/popular posts from blog/portfolio)
		$options[] = array( "name" => "Sidebar posts (recent/popular posts from blog/portfolio)",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_sidebar_posts_height",
								"std" => "105",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_sidebar_posts_crop",
								"std" => "1",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// WordPress default galleries
		$options[] = array( "name" => "WordPress default galleries",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_gallery_height",
								"std" => "200",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_gallery_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// big slider shortcode
		$options[] = array( "name" => "Big slider shortcode",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_big_slider_shortcode_height",
								"std" => "375",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_big_slider_shortcode_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);

		// medium slider shortcode
		$options[] = array( "name" => "Medium slider shortcode",
							"type" => "toggle-start",
							"location" => IMAGE_SIZES_PAGE);
						
			$options[] = array( "name" => "Image height",
								"desc" => "",
								"id" => "advanced_image_size_medium_slider_shortcode_height",
								"std" => "280",
								"type" => "text",
								"class" => "image-size",
								"location" => IMAGE_SIZES_PAGE);

			$options[] = array( "name" => "Crop the image?",
								"desc" => "",
								"id" => "advanced_image_size_medium_slider_shortcode_crop",
								"std" => "1",
								"class" => "hidden",
								"type" => "checkbox",
								"location" => IMAGE_SIZES_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => IMAGE_SIZES_PAGE);
							
	// SKINS MANAGER -------------------------------------------------------------------
	$options[] = array( "name" => "Tasks",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Current skin:",
							"desc" => "",
							"id" => "skin_current",
							"type" => "skin_current",
							"class" => "mini",
							"std" => "_theme_Mixx_Wide",
							"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Create a new skin:",
							"desc" => "",
							"id" => "skin_create",
							"type" => "skin_create",
							"class" => "mini",
							"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Delete skin:",
							"desc" => "",
							"id" => "skin_delete",
							"type" => "skin_delete",
							"class" => "small",
							"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Export current skin:",
							"desc" => "",
							"id" => "skin_export",
							"type" => "skin_export",
							"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Import new skin:",
							"desc" => "",
							"id" => "skin_import",
							"type" => "skin_import",
							"class" => "mini",
							"location" => SKINS_MANAGER_PAGE);

	$options[] = array( "name" => "Colors",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		// BODY, TEXT, HEADINGS AND LINKS				
		$options[] = array( "name" => "Body, Text, Headings and Links",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Body background color",
								"desc" => "",
								"id" => "skin_body_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Body text color",
								"desc" => "Main body text color used throughout the site.",
								"id" => "skin_body_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Link color",
								"desc" => "Link color used throughout the site.",
								"id" => "skin_link_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Link hover color",
								"desc" => "Link hover color used throughout the site.",
								"id" => "skin_link_hover_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Headings color",
								"desc" => "H1, H2, H3, H4 headings color used in pages/posts description.",
								"id" => "skin_heading_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Headings alternate color",
								"desc" => "H5, H6 headings and some sub-titles color (call-to-action shortcode for example).",
								"id" => "skin_heading_alt_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// SUPERIOR-HEADER BAR
		$options[] = array( "name" => "Superior-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Superior-header bar container background color",
								"desc" => "Full width superior-header bar container background color.",
								"id" => "skin_superior_header_bar_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Superior-header bar background color",
								"desc" => "Fixed width superior-header bar background color.",
								"id" => "skin_superior_header_bar_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Superior-header bar text color",
								"desc" => "",
								"id" => "skin_superior_header_bar_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// HEADER, MENU AND SEARCH FIELD
		$options[] = array( "name" => "Header, Menu and Search Field",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Header container background color",
								"desc" => "Full width header container background color.",
								"id" => "skin_header_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Header background color",
								"desc" => "Fixed width header background color.",
								"id" => "skin_header_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Menu bar container background color",
								"desc" => "Full width menu bar container background color.",
								"id" => "skin_header_menu_bar_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Menu bar background color",
								"desc" => "Fixed width menu bar background color.",
								"id" => "skin_header_menu_bar_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Menu text color",
								"desc" => "",
								"id" => "skin_header_menu_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Menu selected text color",
								"desc" => "",
								"id" => "skin_header_menu_selected_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Menu hover text color",
								"desc" => "",
								"id" => "skin_header_menu_hover_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Menu hover background color",
								"desc" => "",
								"id" => "skin_header_menu_hover_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-Menu text color",
								"desc" => "",
								"id" => "skin_header_sub_menu_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-Menu hover text color",
								"desc" => "",
								"id" => "skin_header_sub_menu_hover_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-Menu background color",
								"desc" => "",
								"id" => "skin_header_sub_menu_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-Menu hover background color",
								"desc" => "",
								"id" => "skin_header_sub_menu_hover_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Header search field text color",
								"desc" => "",
								"id" => "skin_header_search_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Header search field background color",
								"desc" => "",
								"id" => "skin_header_search_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Header search field focus text color",
								"desc" => "",
								"id" => "skin_header_search_focus_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);			
								
			$options[] = array( "name" => "Header search field focus background color",
								"desc" => "",
								"id" => "skin_header_search_focus_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);								

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// SUB-HEADER BAR
		$options[] = array( "name" => "Sub-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar container background color",
								"desc" => "Full width sub-header bar container background color.",
								"id" => "skin_sub_header_bar_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header bar text color",
								"desc" => "",
								"id" => "skin_sub_header_bar_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar background",
								"desc" => "",
								"id" => "skin_sub_header_bar_bg_select",
								"std" => "solid",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar background color",
								"desc" => "",
								"id" => "skin_sub_header_bar_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar text background",
								"desc" => "",
								"id" => "skin_sub_header_bar_text_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar text background color",
								"desc" => "",
								"id" => "skin_sub_header_bar_text_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);
							
		// SUB-HEADER SLIDER
		$options[] = array( "name" => "Sub-header slider",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider container background color",
								"desc" => "Full width sub-header slider container background color.",
								"id" => "skin_sub_header_slider_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header slider background color",
								"desc" => "Fixed width sub-header slider background color.",
								"id" => "skin_sub_header_slider_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header slider title text color",
								"desc" => "",
								"id" => "skin_sub_header_slider_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider description text color",
								"desc" => "",
								"id" => "skin_sub_header_slider_description_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider description link color",
								"desc" => "",
								"id" => "skin_sub_header_slider_description_link_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider description link hover color",
								"desc" => "",
								"id" => "skin_sub_header_slider_description_link_hover_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider text background",
								"desc" => "",
								"id" => "skin_sub_header_slider_text_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider text background color",
								"desc" => "",
								"id" => "skin_sub_header_slider_text_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider navigation buttons background color",
								"desc" => "",
								"id" => "skin_sub_header_slider_navigation_buttons_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider navigation buttons arrow color",
								"desc" => "",
								"id" => "skin_sub_header_slider_navigation_buttons_arrow_color",
								"std" => "black",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);
							
		// MAIN AREA
		$options[] = array( "name" => "Main Area and Sidebar Widgets",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Main area container background color",
								"desc" => "",
								"id" => "skin_main_area_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Main area background color",
								"desc" => "",
								"id" => "skin_main_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Main area separators color",
								"desc" => "",
								"id" => "skin_main_area_separators_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sidebar widgets title text color",
								"desc" => "",
								"id" => "skin_sidebar_widgets_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sidebar widgets title background",
								"desc" => "",
								"id" => "skin_sidebar_widgets_title_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sidebar widgets title background color",
								"desc" => "",
								"id" => "skin_sidebar_widgets_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// FOOTER WIDGETS AREA
		$options[] = array( "name" => "Footer Widgets Area and Footer Widgets",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets area container background color",
								"desc" => "Full width footer widgets area container background color.",
								"id" => "skin_footer_widgets_area_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Footer widgets area background color",
								"desc" => "Fixed width footer widgets area background color.",
								"id" => "skin_footer_widgets_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets area separators color",
								"desc" => "",
								"id" => "skin_footer_widgets_area_separators_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets title text color",
								"desc" => "",
								"id" => "skin_footer_widgets_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets title background",
								"desc" => "",
								"id" => "skin_footer_widgets_title_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets title background color",
								"desc" => "",
								"id" => "skin_footer_widgets_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets content text color",
								"desc" => "",
								"id" => "skin_footer_widgets_content_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets content links color",
								"desc" => "",
								"id" => "skin_footer_widgets_content_links_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets content links hover color",
								"desc" => "",
								"id" => "skin_footer_widgets_content_links_hover_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	
							
		// FOOTER
		$options[] = array( "name" => "Footer",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer area container background color",
								"desc" => "Full width footer area container background color.",
								"id" => "skin_footer_area_container_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Footer area background color",
								"desc" => "Fixed width footer area background color.",
								"id" => "skin_footer_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer content links color",
								"desc" => "",
								"id" => "skin_footer_content_links_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer content text color",
								"desc" => "",
								"id" => "skin_footer_content_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	
							
		// PORTFOLIO LISTINGS
		$options[] = array( "name" => "Portfolio Listings",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings title text color",
								"desc" => "",
								"id" => "skin_portfolio_listings_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings description text color",
								"desc" => "",
								"id" => "skin_portfolio_listings_description_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings overlay/title background",
								"desc" => "",
								"id" => "skin_portfolio_listings_overlay_title_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options_no_transparent,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings overlay/title background color",
								"desc" => "",
								"id" => "skin_portfolio_listings_overlay_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings bottom right button background color",
								"desc" => "",
								"id" => "skin_portfolio_listings_bottom_right_button_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings bottom right button icon color",
								"desc" => "",
								"id" => "skin_portfolio_listings_bottom_right_button_icon_color",
								"std" => "black",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings bottom right button hover background color",
								"desc" => "",
								"id" => "skin_portfolio_listings_bottom_right_button_hover_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Portfolio listings bottom right button hover icon color",
								"desc" => "",
								"id" => "skin_portfolio_listings_bottom_right_button_hover_icon_color",
								"std" => "white",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	
							
		// BLOG
		$options[] = array( "name" => "Blog",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post title text color",
								"desc" => "",
								"id" => "skin_blog_post_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post title text background (alternate blog template only)",
								"desc" => "",
								"id" => "skin_blog_post_title_bg_select",
								"std" => "solid",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options_no_transparent,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post title text background color (alternate blog template only)",
								"desc" => "",
								"id" => "skin_blog_post_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post permalink icon color",
								"desc" => "",
								"id" => "skin_blog_post_permalink_icon_color",
								"std" => "black",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post bottom right button background color",
								"desc" => "",
								"id" => "skin_blog_post_bottom_right_button_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post bottom right button icon color",
								"desc" => "",
								"id" => "skin_blog_post_bottom_right_button_icon_color",
								"std" => "black",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post bottom right button hover background color",
								"desc" => "",
								"id" => "skin_blog_post_bottom_right_button_hover_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Blog post bottom right button hover icon color",
								"desc" => "",
								"id" => "skin_blog_post_bottom_right_button_hover_icon_color",
								"std" => "white",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Status, Quote and Link post formats link and text color",
								"desc" => "",
								"id" => "skin_blog_post_status_quote_link_post_formats_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Status, Quote and Link post formats background",
								"desc" => "",
								"id" => "skin_blog_post_status_quote_link_post_formats_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options_no_transparent,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Status, Quote and Link post formats background color",
								"desc" => "",
								"id" => "skin_blog_post_status_quote_link_post_formats_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Status, Quote and Link post formats icon color",
								"desc" => "",
								"id" => "skin_blog_post_status_quote_link_post_formats_icon_color",
								"std" => "white",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// Input fields (in Main Area)
		$options[] = array( "name" => "Input fields (in Main Area)",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Input field text color",
								"desc" => "",
								"id" => "skin_input_main_area_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Input field background color",
								"desc" => "",
								"id" => "skin_input_main_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Input field border color",
								"desc" => "",
								"id" => "skin_input_main_area_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Input field focus text color",
								"desc" => "",
								"id" => "skin_input_main_area_focus_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);			
								
			$options[] = array( "name" => "Input field focus background color",
								"desc" => "",
								"id" => "skin_input_main_area_focus_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Input field focus border color",
								"desc" => "",
								"id" => "skin_input_main_area_focus_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// Input fields (in Footer Area)
		$options[] = array( "name" => "Input fields (in Footer Area)",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Input field text color",
								"desc" => "",
								"id" => "skin_input_footer_area_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Input field background color",
								"desc" => "",
								"id" => "skin_input_footer_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Input field border color",
								"desc" => "",
								"id" => "skin_input_footer_area_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Input field focus text color",
								"desc" => "",
								"id" => "skin_input_footer_area_focus_font_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);			
								
			$options[] = array( "name" => "Input field focus background color",
								"desc" => "",
								"id" => "skin_input_footer_area_focus_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	
			
			$options[] = array( "name" => "Input field focus border color",
								"desc" => "",
								"id" => "skin_input_footer_area_focus_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// BUTTON (SHORTCODE)
		$options[] = array( "name" => "Button Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Button background color",
								"desc" => "",
								"id" => "skin_button_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Button text color",
								"desc" => "",
								"id" => "skin_button_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Button hover background color",
								"desc" => "",
								"id" => "skin_button_hover_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Button hover text color",
								"desc" => "",
								"id" => "skin_button_hover_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// CALL TO ACTION BAR (SHORTCODE)
		$options[] = array( "name" => "Call-to-action Bar Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Call-to-action bar background color",
								"desc" => "",
								"id" => "skin_call_to_action_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Call-to-action bar text color",
								"desc" => "",
								"id" => "skin_call_to_action_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// GALLERY (SHORTCODE)
		$options[] = array( "name" => "Gallery Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Gallery background",
								"desc" => "",
								"id" => "skin_gallery_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Gallery background color",
								"desc" => "",
								"id" => "skin_gallery_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// INFO BOX (SHORTCODE)
		$options[] = array( "name" => "Info Box Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Info box title background color",
								"desc" => "",
								"id" => "skin_info_box_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Info box title text color",
								"desc" => "",
								"id" => "skin_info_box_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Info box content background color",
								"desc" => "",
								"id" => "skin_info_box_content_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Info box content text color",
								"desc" => "",
								"id" => "skin_info_box_content_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// HIGHLIGHT (SHORTCODE)
		$options[] = array( "name" => "Highlight Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Highlight background color",
								"desc" => "",
								"id" => "skin_highlight_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Highlight text color",
								"desc" => "",
								"id" => "skin_highlight_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// PRICE TABLES (SHORTCODE)
		$options[] = array( "name" => "Price Table Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Featured column main color",
								"desc" => "",
								"id" => "skin_price_table_featured_main_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Featured column background color",
								"desc" => "",
								"id" => "skin_price_table_featured_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Column main color",
								"desc" => "",
								"id" => "skin_price_table_column_main_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Column background color",
								"desc" => "",
								"id" => "skin_price_table_column_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Alternating column main color",
								"desc" => "",
								"id" => "skin_price_table_alt_column_main_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Alternating column background color",
								"desc" => "",
								"id" => "skin_price_table_alt_column_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// SLIDERS (SHORTCODE)
		$options[] = array( "name" => "Slider Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode background color",
								"desc" => "",
								"id" => "skin_slider_shortcode_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Slider shortcode title text color",
								"desc" => "",
								"id" => "skin_slider_shortcode_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode description text color",
								"desc" => "",
								"id" => "skin_slider_shortcode_description_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode description link color",
								"desc" => "",
								"id" => "skin_slider_shortcode_description_link_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode description link hover color",
								"desc" => "",
								"id" => "skin_slider_shortcode_description_link_hover_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);


			$options[] = array( "name" => "Slider shortcode text background",
								"desc" => "",
								"id" => "skin_slider_shortcode_text_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode text background color",
								"desc" => "",
								"id" => "skin_slider_shortcode_text_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Slider shortcode navigation buttons arrow color",
								"desc" => "",
								"id" => "skin_slider_shortcode_navigation_buttons_arrow_color",
								"std" => "black",
								"type" => "select",
								"class" => "mini",
								"options" => $button_background_options,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// TABS (SHORTCODE)
		$options[] = array( "name" => "Tabs Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Tabs background color",
								"desc" => "",
								"id" => "skin_tabs_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Tabs border color",
								"desc" => "",
								"id" => "skin_tabs_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// TOGGLE (SHORTCODE)
		$options[] = array( "name" => "Toggle Shortcode",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Toggle title background color",
								"desc" => "",
								"id" => "skin_toggle_title_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Toggle title text color",
								"desc" => "",
								"id" => "skin_toggle_title_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Toggle content background color",
								"desc" => "",
								"id" => "skin_toggle_content_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Toggle content text color",
								"desc" => "",
								"id" => "skin_toggle_content_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// PRE, CODE, TABLE and Ad widgets (in Main Area)
		$options[] = array( "name" => "PRE, CODE, TABLE, Ad widget and Woocomerce messages (in Main Area)",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Border color:",
								"desc" => "",
								"id" => "skin_ad_main_area_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Background color:",
								"desc" => "",
								"id" => "skin_ad_main_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Text color:",
								"desc" => "",
								"id" => "skin_ad_main_area_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// PRE, CODE, TABLE and Ad widgets (in Footer Area)
		$options[] = array( "name" => "PRE, CODE, TABLE and Ad widgets (in Footer Area)",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Border color:",
								"desc" => "",
								"id" => "skin_ad_footer_area_border_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Background color:",
								"desc" => "",
								"id" => "skin_ad_footer_area_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Text color:",
								"desc" => "",
								"id" => "skin_ad_footer_area_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// WOOCOMMERCE
		$options[] = array( "name" => "Woocommerce",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Old price color:",
								"desc" => "",
								"id" => "skin_woocommerce_del_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sale badge text color:",
								"desc" => "",
								"id" => "skin_woocommerce_sale_text_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sale badge background",
								"desc" => "",
								"id" => "skin_woocommerce_sale_bg_select",
								"std" => "dark",
								"type" => "select",
								"class" => "mini bgselect",
								"options" => $background_options_no_transparent,
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sale badge background color",
								"desc" => "",
								"id" => "skin_woocommerce_sale_bgcolor",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Price filter widget line color",
								"desc" => "",
								"id" => "skin_woocommerce_price_filter_color",
								"std" => "",
								"type" => "color",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

	$options[] = array( "name" => "Background Images",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "IMPORTANT NOTICE:",
						"type" => "info",
						"desc" => "When setting these background images make sure to upload them using the upload fields below so that the images get copied to the correct skin folder or else you may run into unexpected problems.",
						"location" => SKINS_MANAGER_PAGE);

		// FULL PAGE
		$options[] = array( "name" => "Full page",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Full page background image",
								"desc" => "This image is centered and covers all the page background while maintaining aspect ratio (overlaps the body background image).",
								"id" => "skin_full_page_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);
								
		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// BODY	
		$options[] = array( "name" => "Body",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Body background image",
								"desc" => "",
								"id" => "skin_body_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// SUPERIOR-HEADER BAR
		$options[] = array( "name" => "Superior-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Superior-header bar container background image",
								"desc" => "Full width superior-header bar container background image.",
								"id" => "skin_superior_header_bar_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Superior-header bar background image",
								"desc" => "Fixed width superior-header bar background image.",
								"id" => "skin_superior_header_bar_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// HEADER AND MENU
		$options[] = array( "name" => "Header and Menu",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Header container background image",
								"desc" => "Full width header container background image.",
								"id" => "skin_header_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Header background image",
								"desc" => "Fixed width header background image.",
								"id" => "skin_header_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Menu bar container background image",
								"desc" => "Full width menu bar container background image.",
								"id" => "skin_header_menu_bar_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Menu bar background image",
								"desc" => "Fixed width menu bar background image.",
								"id" => "skin_header_menu_bar_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);

		// SUB-HEADER BAR
		$options[] = array( "name" => "Sub-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar container background image",
								"desc" => "Full width sub-header bar container background image.",
								"id" => "skin_sub_header_bar_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header bar image",
								"des",
								"id" => "skin_sub_header_bar_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);
							
		// SUB-HEADER SLIDER
		$options[] = array( "name" => "Sub-header slider",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Sub-header slider container background image",
								"desc" => "(normal slider)",
								"id" => "skin_sub_header_slider_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header slider background image",
								"desc" => "(normal slider)",
								"id" => "skin_sub_header_slider_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header full-width slider container background image",
								"desc" => "(full-width)",
								"id" => "skin_sub_header_full_width_slider_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Sub-header full-width slider background image",
								"desc" => "(full-width)",
								"id" => "skin_sub_header_full_width_slider_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);
							
		// MAIN AREA
		$options[] = array( "name" => "Main Area",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Main area container background image",
								"desc" => "",
								"id" => "skin_main_area_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Main area background image",
								"desc" => "",
								"id" => "skin_main_area_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// FOOTER WIDGETS AREA
		$options[] = array( "name" => "Footer Widgets Area",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer widgets area container background image",
								"desc" => "Full width footer widgets area container background image.",
								"id" => "skin_footer_widgets_area_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Footer widgets area background image",
								"desc" => "Fixed width footer widgets area background image.",
								"id" => "skin_footer_widgets_area_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	
							
		// FOOTER
		$options[] = array( "name" => "Footer",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Footer area container background image",
								"desc" => "Full width footer area container background image.",
								"id" => "skin_footer_area_container_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);	

			$options[] = array( "name" => "Footer area background image",
								"desc" => "Fixed width footer area background image.",
								"id" => "skin_footer_area_bgimage",
								"std" => $background_defaults, 
								"type" => "background",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

	// FONTS
	$options[] = array( "name" => "Fonts",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "IMPORTANT NOTICE:",
							"type" => "info",
							"desc" => "Not all fonts support all font weights and styles, for more information please check the <a href=\"http://www.google.com/webfonts\">Google web fonts directory</a>.",
							"location" => SKINS_MANAGER_PAGE);

		// FALLBACK FONT FAMILY
		$options[] = array( "name" => "Fallback font family",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This is the default fallback font family applied when for any particular reason the Cufon or Google web fonts don't load.",
								"id" => "fonts_fallback_font_family",
								"std" => array('face' => '"Helvetica Neue", Helvetica, Arial, sans-serif'),
								"type" => "typography",
								"advanced" => false,
								"size" => false,
								"lineheight" => false,
								"fontstyle" => false,
								"uppercase" => false,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// BODY FONT
		$options[] = array( "name" => "Body font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applyed to the body text. You can't set a Cufon font for the body because it will probably crash your User's browser.",
								"id" => "fonts_body_font_family",
								"std" => array('face' => '', 'size' => '13px', 'lineheight' => '21px'),
								"type" => "typography",
								"advanced" => true,
								"size" => true,
								"lineheight" => true,
								"fontstyle" => false,
								"uppercase" => false,
								"cufon_fonts" => false,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// TOP NAVIGATION MENU FONT
		$options[] = array( "name" => "Top navigation menu font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the top navigation menu parent elements.",
								"id" => "fonts_top_nav_menu_font",
								"std" => array('face' => '', 'size' => '12px', 'fontstyle' => '700', 'uppercase' => 'on'),
								"type" => "typography",
								"advanced" => true,
								"size" => true,
								"lineheight" => false,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// SUB-HEADER BAR TITLE FONT
		$options[] = array( "name" => "Sub-header bar title font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the sub-header bar title.",
								"id" => "fonts_sub_header_bar_title_font",
								"std" => array('face' => '', 'size' => '70px', 'lineheight' => '70px', 'fontstyle' => '400', 'uppercase' => 'off'),
								"type" => "typography",
								"advanced" => true,
								"size" => true,
								"lineheight" => true,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// SUB-HEADER BAR DESCRIPTION FONT
		$options[] = array( "name" => "Sub-header bar description font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the sub-header bar description.",
								"id" => "fonts_sub_header_bar_description_font",
								"std" => array('face' => '', 'size' => '10px', 'lineheight' => '20px', 'fontstyle' => '700', 'uppercase' => 'on'),
								"type" => "typography",
								"advanced" => true,
								"size" => true,
								"lineheight" => true,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// HEADING AND BLOG POST TITLES FONT
		$options[] = array( "name" => "Headings and blog post titles font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the headings (h1, h2, h3, h4, h5, h6) and blog post titles.",
								"id" => "fonts_headings_font",
								"std" => array('face' => ''),
								"type" => "typography",
								"advanced" => true,
								"size" => false,
								"lineheight" => false,
								"fontstyle" => false,
								"uppercase" => false,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// WIDGET TITLES FONT
		$options[] = array( "name" => "Widget titles font",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the widget titles.",
								"id" => "fonts_widget_titles_font",
								"std" => array('face' => '', 'size' => '12px', 'lineheight' => '24px', 'fontstyle' => '700', 'uppercase' => 'on'),
								"type" => "typography",
								"advanced" => true,
								"size" => true,
								"lineheight" => true,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// TITLES FONT IN PORTFOLIO TEMPLATES WITH HOVER EFFECT AND 1 COLUMN PORTFOLIO TEMPLATE
		$options[] = array( "name" => "Titles font in portfolio templates with hover effect",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the titles in portfolio items using the hover effect portfolio templates.",
								"id" => "fonts_portfolio_title_with_hover_effect_font",
								"std" => array('face' => '', 'fontstyle' => '700', 'uppercase' => 'on'),
								"type" => "typography",
								"advanced" => true,
								"size" => false,
								"lineheight" => false,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	
							
		// TITLES FONT IN PORTFOLIO TEMPLATES WITH DESCRIPTION
		$options[] = array( "name" => "Titles font in portfolio templates with description and 1 column portfolio templates",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "This font is applied to the titles inside portfolio templates with description and 1 column portfolio templates.",
								"id" => "fonts_portfolio_title_with_description_font",
								"std" => array('face' => '', 'fontstyle' => '700', 'uppercase' => 'on'),
								"type" => "typography",
								"advanced" => true,
								"size" => false,
								"lineheight" => false,
								"fontstyle" => true,
								"uppercase" => true,
								"cufon_fonts" => $cufon_fonts,
								"google_fonts" => $google_fonts,
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// OTHER FONT OPTIONS
		$options[] = array( "name" => "Other font options",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show post meta information in uppercase?",
								"id" => "fonts_show_posts_meta_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show sortable portfolio categories in uppercase?",
								"id" => "fonts_show_sortable_portfolio_categories_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show info box shortcode titles in uppercase?",
								"id" => "fonts_show_info_box_title_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show price table column titles in uppercase?",
								"id" => "fonts_show_price_column_title_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show slider titles in uppercase?",
								"id" => "fonts_show_slider_title_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "",
								"desc" => "Show toggle shortcode titles in uppercase?",
								"id" => "fonts_show_toggle_title_uppercase",
								"std" => "1",
								"type" => "checkbox",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

	$options[] = array( "name" => "Other Settings",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		// SUPERIOR-HEADER BAR
		$options[] = array( "name" => "Superior-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Width",
								"desc" => "",
								"id" => "skin_superior_header_bar_width",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "960" => "960px", "1020" => "1020px" ),
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Height",
								"desc" => "",
								"id" => "skin_superior_header_bar_height",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "disabled" => "0px (hide)", "7" => "7px", "30" => "30px" ),
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Left and right padding",
								"desc" => "px",
								"id" => "skin_superior_header_bar_side_padding",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// HEADER
		$options[] = array( "name" => "Header",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Height",
								"desc" => "px",
								"id" => "skin_header_height",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// LOGO
		$options[] = array( "name" => "Logo",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Top margin",
								"desc" => "px",
								"id" => "skin_logo_top_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Left margin",
								"desc" => "px",
								"id" => "skin_logo_left_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// MENU BAR
		$options[] = array( "name" => "Menu bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Width",
								"desc" => "",
								"id" => "skin_menu_bar_width",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "960px" => "960px", "1020px" => "1020px", "auto" => "Fit" ),
								"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Top margin",
								"desc" => "px",
								"id" => "skin_menu_bar_top_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Right margin",
								"desc" => "px",
								"id" => "skin_menu_bar_right_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// SUB-HEADER BAR
		$options[] = array( "name" => "Sub-header bar",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Width",
								"desc" => "",
								"id" => "skin_header_bar_width",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "960" => "960px", "1020" => "1020px" ),
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Height",
								"desc" => "px",
								"id" => "skin_header_bar_height",
								"std" => "150",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Height when there isn't a description present",
								"desc" => "px",
								"id" => "skin_header_bar_height_no_description",
								"std" => "100",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Title top margin",
								"desc" => "px",
								"id" => "skin_header_bar_title_top_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Title top margin (when there isn't a description present)",
								"desc" => "px",
								"id" => "skin_header_bar_title_top_margin_no_description",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Title left margin",
								"desc" => "px",
								"id" => "skin_header_bar_title_left_margin_with_bg",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Title left margin (when the sub-header background is transparent)",
								"desc" => "px",
								"id" => "skin_header_bar_title_left_margin_without_bg",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Description top margin",
								"desc" => "px",
								"id" => "skin_header_bar_description_top_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Description left margin",
								"desc" => "px",
								"id" => "skin_header_bar_description_left_margin_with_bg",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Description left margin (when the sub-header background is transparent)",
								"desc" => "px",
								"id" => "skin_header_bar_description_left_margin_without_bg",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// SUB-HEADER SLIDER
		$options[] = array( "name" => "Sub-header slider",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Width",
								"desc" => "",
								"id" => "skin_header_slider_width",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "960" => "960px", "1020" => "1020px" ),
								"location" => SKINS_MANAGER_PAGE);
								
			$options[] = array( "name" => "Height",
								"desc" => "px",
								"id" => "skin_header_slider_height",
								"std" => "400",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// SUB-HEADER FULL WIDTH SLIDER
		$options[] = array( "name" => "Sub-header full width slider",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Height",
								"desc" => "px",
								"id" => "skin_header_full_width_slider_height",
								"std" => "574",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Video width",
								"desc" => "",
								"id" => "skin_header_full_width_slider_video_width",
								"std" => "",
								"type" => "select",
								"class" => "mini",
								"options" => array( "960" => "960px", "1020" => "1020px" ),
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Top margin",
								"desc" => "px (use a negative value to move the slider up behind the header)",
								"id" => "skin_header_full_width_slider_top_margin",
								"std" => "",
								"type" => "text",
								"class" => "mini",
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

		// BUTTONS (SHORTCODE)
		$options[] = array( "name" => "Buttons",
							"type" => "toggle-start",
							"location" => SKINS_MANAGER_PAGE);
			
			$options[] = array( "name" => "Form submit button type",
								"desc" => "",
								"id" => "skin_submit_button_type",
								"std" => "normal",
								"type" => "select",
								"class" => "mini",
								"options" => array( 'normal' => 'Normal', 'fancy' => 'Fancy' ),
								"location" => SKINS_MANAGER_PAGE);

			$options[] = array( "name" => "Form submit button corners type",
								"desc" => "",
								"id" => "skin_submit_button_corners",
								"std" => "subtle",
								"type" => "select",
								"class" => "mini",
								"options" => array( 'flat' => 'Flat corners', 'subtle' => 'Subtle rounded corners', 'rounded' => 'Rounded corners' ),
								"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "type" => "toggle-end",
							"location" => SKINS_MANAGER_PAGE);	

	$options[] = array( "name" => "Custom CSS",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Custom CSS",
							"desc" => "Add your custom css entries here. These styles are included when you export the skin.",
							"id" => "skin_custom_css",
							"std" => "",
							"type" => "textarea",
							"location" => SKINS_MANAGER_PAGE); 

	$options[] = array( "name" => "Download Skins +",
						"type" => "heading",
						"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "Skin Browser",
							"desc" => "This is a list of extra skins that you can install to your theme without having to re-download the theme zip file from ThemeForest. I will be adding new skins and you can contribute too, just export the skin you've designed, host the file on a server and send me the link by contacting me using my <a href=\"http://themeforest.net/user/unisphere\" target=\"_blank\">ThemeForest profile</a> contact form.",
							"type" => "info",
							"location" => SKINS_MANAGER_PAGE);

		$options[] = array( "name" => "",
							"desc" => "",
							"id" => "skin_browser",							
							"type" => "skin_browser",
							"std" => "",
							"location" => SKINS_MANAGER_PAGE); 

	// SIDEBAR MANAGER -------------------------------------------------------------------
	$options[] = array( "name" => "",
						"type" => "heading",
						"location" => SIDEBAR_MANAGER_PAGE);
							
		$options[] = array( "name" => "Create new custom sidebar:",
							"desc" => "",
							"id" => "sidebar_create",
							"type" => "sidebar_create",
							"class" => "mini",
							"std" => "",
							"location" => SIDEBAR_MANAGER_PAGE);

		$options[] = array( "name" => "Available custom sidebars:",
							"desc" => "",
							"id" => "sidebar_list",
							"type" => "sidebar_list",
							"std" => "",
							"location" => SIDEBAR_MANAGER_PAGE);

	// FONTS MANAGER -------------------------------------------------------------------
	$options[] = array( "name" => "Google Web Fonts Settings",
						"type" => "heading",
						"location" => FONTS_MANAGER_PAGE);

		$options[] = array( "name" => "Update available Google web fonts",
							"desc" => "The number of available fonts in the Google web font directory is constantly being updated, hit the \"Update\" button to grab the latest list of fonts. You can preview the available fonts in the <a href=\"http://www.google.com/webfonts\">Google web fonts directory</a>.",
							"id" => "fonts_update_google",
							"type" => "fonts_update_google",
							"std" => "",
							"location" => FONTS_MANAGER_PAGE);

		$options[] = array( "name" => "Include the following font subsets:",
							"desc" => "NOTE: not all fonts support all subsets, for more information please check the <a href=\"http://www.google.com/webfonts\">Google web fonts directory</a>.",
							"id" => "fonts_subsets_google",
							"std" => "",
							"type" => "multicheck",
							"options" => $font_subsets_defaults,
							"location" => FONTS_MANAGER_PAGE);

	$options[] = array( "name" => "Cufon Fonts Settings",
						"type" => "heading",
						"location" => FONTS_MANAGER_PAGE);

		$options[] = array( "name" => "Add new Cufon font:",
							"desc" => "",
							"id" => "cufon_upload",
							"type" => "cufon_upload",
							"class" => "mini",
							"location" => FONTS_MANAGER_PAGE);

	return $options;
}
?>
