<?php
/**
 * Ads Widget
 */


/**
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'unisphere_load_ads_widget' );


/**
 * Register our widget.
 * 'UniSphere_Ads_Widget' is the widget class used below.
 */
function unisphere_load_ads_widget() {
	register_widget( 'UniSphere_Ads_Widget' );
}


/**
 * UniSphere_Ads_Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 */
class UniSphere_Ads_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function UniSphere_Ads_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'widget-ads', 'description' => 'An advertising banner' );

		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'unisphere-ads-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'unisphere-ads-widget', 'UniSphere Ads', $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$image_url = $instance['image_url'];
		$destination_url = $instance['destination_url'];
		$description = $instance['description'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by theme). */
		if ( $title )
			echo $before_title . $title . $after_title;

		/* Display ad */
		echo '<div class="widget-ad">';
		echo '<a href="' . $destination_url . '" class="no-underline"><img src="' . $image_url . '" alt="" /></a>';
		echo '<small>' . $description . '</small>';
		echo '</div>';

		/* After widget (defined by theme). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['image_url'] = strip_tags( $new_instance['image_url'] );
		$instance['destination_url'] = strip_tags( $new_instance['destination_url'] );
		$instance['description'] = $new_instance['description'];

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array();
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
        
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php if( isset( $instance['title'] ) ) echo $instance['title']; ?>" class="widefat" />
		</p>
        
		<!-- Widget Image URL: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'image_url' ); ?>">Image URL:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'image_url' ); ?>" name="<?php echo $this->get_field_name( 'image_url' ); ?>" value="<?php if( isset( $instance['image_url'] ) ) echo $instance['image_url']; ?>" class="widefat" />
		</p>

		<!-- Widget Destination URL: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'destination_url' ); ?>">Destination URL:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'destination_url' ); ?>" name="<?php echo $this->get_field_name( 'destination_url' ); ?>" value="<?php if( isset( $instance['destination_url'] ) ) echo $instance['destination_url']; ?>" class="widefat" />
		</p>

		<!-- Widget Description: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'description' ); ?>">Description:</label>
			<textarea id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" cols="20" rows="5" class="widefat"><?php if( isset( $instance['description'] ) ) echo $instance['description']; ?></textarea>
		</p>

	<?php
	}
}
?>