<?php

// Change the Woocommerce containers to better suite the theme's HTML structure
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

function unisphere_woocommerce_before_main_content() {
	echo "<div id=\"primary\" class=\"woocommerce" . ( unisphere_is_active_sidebar("main-sidebar") ? "" : " no-sidebar" ) . "\">";
	echo '<script type="text/javascript">';
		echo 'jQuery(document).ready(function() {';	
			echo 'jQuery(".menu li.current_page_parent").removeClass("current_page_parent");';
			echo 'jQuery(".menu li.page-item-' . woocommerce_get_page_id('shop') . '").addClass("current_page_item");';
			echo 'mobileNav();';
		echo '});';	
	echo '</script>';
}
add_action('woocommerce_before_main_content', 'unisphere_woocommerce_before_main_content', 10);

function unisphere_woocommerce_after_main_content() {
	echo "</div>";
}
add_action('woocommerce_after_main_content', 'unisphere_woocommerce_after_main_content', 10);


// Hide Cart buttons on the shop product lists
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);
function unisphere_woocommerce_template_loop_add_to_cart() {
	if( !is_shop() && !is_product_category() && !is_product_tag() ) {
		return woocommerce_template_loop_add_to_cart();
	}
}
add_action( 'woocommerce_after_shop_loop_item', 'unisphere_woocommerce_template_loop_add_to_cart', 10);


// Remove the Woocommerce breadcrumbs
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
function unisphere_woocommerce_breadcrumb( ) {
	return null;
}
add_action( 'woocommerce_before_main_content', 'unisphere_woocommerce_breadcrumb', 20);


// Change number or products per row based on the existence of a sidebar
add_filter('loop_shop_columns', 'unisphere_loop_shop_columns');
function unisphere_loop_shop_columns() {
	if( is_woocommerce() && unisphere_is_active_sidebar('main-sidebar') )
		return 3;
	else
		return 4;
}


// Display 24 products per page
add_filter('loop_shop_per_page', create_function('$cols', 'return 12;'));


// Replace WooCommerce Default Pagination with WP-PageNavi Pagination
remove_action('woocommerce_pagination', 'woocommerce_pagination', 10);
function unisphere_woocommerce_pagination() {
		include( UNISPHERE_LIBRARY . '/wp-pagenavi.php' );
		if(function_exists('wp_pagenavi')) { wp_pagenavi(); }
	}
add_action( 'woocommerce_pagination', 'unisphere_woocommerce_pagination', 10);


// ------------------------------------------------------------------------------------------------------------
// Change the generated HTML structure for single product pages to better suite the theme
remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10);
remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20);
remove_action('woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);
remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10);
remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);
remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);

// Add next and previous product navigation
function unisphere_next_prev_nav() {
	global $unisphere_options;
	if( isset($unisphere_options['show_woocommerce_navigation_links']) && $unisphere_options['show_woocommerce_navigation_links'] == '1' ) {
		echo '<div id="single-nav">';
			echo '<div id="single-nav-prev">';
				previous_post_link('&larr; %link');
			echo '</div>';
	        echo '<div id="single-nav-next">';
	        	next_post_link('%link &rarr;');
	        echo '</div>';
	    echo '</div>';
	    echo '<div class="hr"><hr/></div>';
	}
}
add_action('woocommerce_before_single_product_summary', 'unisphere_next_prev_nav', 9);

// Open left wrapper
function unisphere_open_left_wrapper() {
	echo '<div class="post-left-wrapper">';
}
add_action('woocommerce_before_single_product_summary', 'unisphere_open_left_wrapper', 10);

// Add price
add_action('woocommerce_before_single_product_summary', 'woocommerce_template_single_price', 20);

// Add meta info
add_action('woocommerce_before_single_product_summary', 'woocommerce_template_single_meta', 30);

// Add share buttons
function unisphere_template_single_sharing() {
	global $unisphere_options;
	if ( $unisphere_options['show_woocommerce_tweet_button'] == '1' || $unisphere_options['show_woocommerce_fb_like_button'] == '1' || $unisphere_options['show_woocommerce_google_plus_button'] == '1') : ?>
        <div class="post-share-buttons">
            <?php if ( $unisphere_options['show_woocommerce_tweet_button'] == '1' ) : ?>
                <div class="twitter-share">
                    <a href="http://twitter.com/share" class="twitter-share-button" data-url="<?php echo get_permalink(); ?>" data-count="none">Tweet</a><script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
                </div>
            <?php endif; ?>
            <?php if ( $unisphere_options['show_woocommerce_fb_like_button'] == '1' ) : ?>
                <div class="facebook-share">
                    <iframe src="//www.facebook.com/plugins/like.php?locale=en_US&amp;href=<?php echo rawurlencode(get_permalink()); ?>&amp;send=false&amp;layout=button_count&amp;width=53&amp;show_faces=false&amp;action=like&amp;colorscheme=light&amp;font&amp;height=20" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:48px; height:20px;" allowTransparency="true"></iframe>
                </div>
            <?php endif; ?>
            <?php if ( $unisphere_options['show_woocommerce_google_plus_button'] == '1' ) : ?>
                <div class="google-plus-share">
                    <div class="g-plusone" data-size="medium" data-annotation="inline" data-href="<?php echo get_permalink(); ?>"></div>
                </div>
            <?php endif; ?>
        </div>
    <?php endif;
}
add_action('woocommerce_before_single_product_summary', 'unisphere_template_single_sharing', 60);

// Close left wrapper
function unisphere_close_left_wrapper() {
	echo '</div>';
}
add_action('woocommerce_before_single_product_summary', 'unisphere_close_left_wrapper', 70);

// Open right wrapper
function unisphere_open_right_wrapper() {
	echo '<div class="post-right-wrapper">';
}
add_action('woocommerce_before_single_product_summary', 'unisphere_open_right_wrapper', 80);

// Open images wrapper
function unisphere_open_images_wrapper() {
	echo '<div class="images-wrapper">';
}
add_action('woocommerce_after_single_product_summary', 'unisphere_open_images_wrapper', 10);

// Add images
add_action('woocommerce_after_single_product_summary', 'woocommerce_show_product_sale_flash', 20);
add_action('woocommerce_after_single_product_summary', 'woocommerce_show_product_images', 30);

// Add thumbnails
add_action('woocommerce_after_single_product_summary', 'woocommerce_show_product_thumbnails', 40 );

// Close images wrapper
function unisphere_close_images_wrapper() {
	echo '</div>';
}
add_action('woocommerce_after_single_product_summary', 'unisphere_close_images_wrapper', 50);

// Close right wrapper
function unisphere_close_right_wrapper() {
	echo '</div><div class="clearfix">&nbsp;</div>';
}
add_action('woocommerce_after_single_product_summary', 'unisphere_close_right_wrapper', 60);

// Add tabs
add_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 70);

// Add a clearfix
function unisphere_related_products_clearfix() {
	echo '<div class="clearfix">&nbsp;</div>';
}
add_action('woocommerce_after_single_product_summary', 'unisphere_related_products_clearfix', 75);

// Add product upsells
add_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 79);

// Add related products (change number or related products in the single product page based on the existence of a sidebar)
function unisphere_woocommerce_output_related_products() {
	if( is_woocommerce() && unisphere_is_active_sidebar('main-sidebar') )
		woocommerce_related_products( 2, 2 ); //posts per page, columns
	else
		woocommerce_related_products( 3, 3 ); //posts per page, columns
}
add_action( 'woocommerce_after_single_product_summary', 'unisphere_woocommerce_output_related_products', 80);
// ------------------------------------------------------------------------------------------------------------

?>
